#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_mipso32 = {
    "_llseek": 4140,
    "_newselect": 4142,
    "_sysctl": 4153,
    "accept": 4168,
    "accept4": 4334,
    "access": 4033,
    "acct": 4051,
    "add_key": 4280,
    "adjtimex": 4124,
    "alarm": 4027,
    "bdflush": 4134,
    "bind": 4169,
    "bpf": 4355,
    "brk": 4045,
    "cachectl": 4148,
    "cacheflush": 4147,
    "capget": 4204,
    "capset": 4205,
    "chdir": 4012,
    "chmod": 4015,
    "chown": 4202,
    "chroot": 4061,
    "clock_adjtime": 4341,
    "clock_adjtime64": 4405,
    "clock_getres": 4264,
    "clock_getres_time64": 4406,
    "clock_gettime": 4263,
    "clock_gettime64": 4403,
    "clock_nanosleep": 4265,
    "clock_nanosleep_time64": 4407,
    "clock_settime": 4262,
    "clock_settime64": 4404,
    "clone": 4120,
    "clone3": 4435,
    "close": 4006,
    "close_range": 4436,
    "connect": 4170,
    "copy_file_range": 4360,
    "creat": 4008,
    "create_module": 4127,
    "delete_module": 4129,
    "dup": 4041,
    "dup2": 4063,
    "dup3": 4327,
    "epoll_create": 4248,
    "epoll_create1": 4326,
    "epoll_ctl": 4249,
    "epoll_pwait": 4313,
    "epoll_pwait2": 4441,
    "epoll_wait": 4250,
    "eventfd": 4319,
    "eventfd2": 4325,
    "execve": 4011,
    "execveat": 4356,
    "exit": 4001,
    "exit_group": 4246,
    "faccessat": 4300,
    "faccessat2": 4439,
    "fadvise64": 4254,
    "fallocate": 4320,
    "fanotify_init": 4336,
    "fanotify_mark": 4337,
    "fchdir": 4133,
    "fchmod": 4094,
    "fchmodat": 4299,
    "fchown": 4095,
    "fchownat": 4291,
    "fcntl": 4055,
    "fcntl64": 4220,
    "fdatasync": 4152,
    "fgetxattr": 4229,
    "finit_module": 4348,
    "flistxattr": 4232,
    "flock": 4143,
    "fork": 4002,
    "fremovexattr": 4235,
    "fsconfig": 4431,
    "fsetxattr": 4226,
    "fsmount": 4432,
    "fsopen": 4430,
    "fspick": 4433,
    "fstat": 4108,
    "fstat64": 4215,
    "fstatat64": 4293,
    "fstatfs": 4100,
    "fstatfs64": 4256,
    "fsync": 4118,
    "ftruncate": 4093,
    "ftruncate64": 4212,
    "futex": 4238,
    "futex_time64": 4422,
    "futimesat": 4292,
    "get_kernel_syms": 4130,
    "get_mempolicy": 4269,
    "get_robust_list": 4310,
    "getcpu": 4312,
    "getcwd": 4203,
    "getdents": 4141,
    "getdents64": 4219,
    "getegid": 4050,
    "geteuid": 4049,
    "getgid": 4047,
    "getgroups": 4080,
    "getitimer": 4105,
    "getpeername": 4171,
    "getpgid": 4132,
    "getpgrp": 4065,
    "getpid": 4020,
    "getpmsg": 4208,
    "getppid": 4064,
    "getpriority": 4096,
    "getrandom": 4353,
    "getresgid": 4191,
    "getresuid": 4186,
    "getrlimit": 4076,
    "getrusage": 4077,
    "getsid": 4151,
    "getsockname": 4172,
    "getsockopt": 4173,
    "gettid": 4222,
    "gettimeofday": 4078,
    "getuid": 4024,
    "getxattr": 4227,
    "idle": 4112,
    "init_module": 4128,
    "inotify_add_watch": 4285,
    "inotify_init": 4284,
    "inotify_init1": 4329,
    "inotify_rm_watch": 4286,
    "io_cancel": 4245,
    "io_destroy": 4242,
    "io_getevents": 4243,
    "io_pgetevents": 4368,
    "io_pgetevents_time64": 4416,
    "io_setup": 4241,
    "io_submit": 4244,
    "io_uring_enter": 4426,
    "io_uring_register": 4427,
    "io_uring_setup": 4425,
    "ioctl": 4054,
    "ioperm": 4101,
    "iopl": 4110,
    "ioprio_get": 4315,
    "ioprio_set": 4314,
    "ipc": 4117,
    "kcmp": 4347,
    "kexec_load": 4311,
    "keyctl": 4282,
    "kill": 4037,
    "landlock_add_rule": 4445,
    "landlock_create_ruleset": 4444,
    "landlock_restrict_self": 4446,
    "lchown": 4016,
    "lgetxattr": 4228,
    "link": 4009,
    "linkat": 4296,
    "listen": 4174,
    "listxattr": 4230,
    "llistxattr": 4231,
    "lookup_dcookie": 4247,
    "lremovexattr": 4234,
    "lseek": 4019,
    "lsetxattr": 4225,
    "lstat": 4107,
    "lstat64": 4214,
    "madvise": 4218,
    "mbind": 4268,
    "membarrier": 4358,
    "memfd_create": 4354,
    "migrate_pages": 4287,
    "mincore": 4217,
    "mkdir": 4039,
    "mkdirat": 4289,
    "mknod": 4014,
    "mknodat": 4290,
    "mlock": 4154,
    "mlock2": 4359,
    "mlockall": 4156,
    "mmap": 4090,
    "mmap2": 4210,
    "modify_ldt": 4123,
    "mount": 4021,
    "mount_setattr": 4442,
    "move_mount": 4429,
    "move_pages": 4308,
    "mprotect": 4125,
    "mq_getsetattr": 4276,
    "mq_notify": 4275,
    "mq_open": 4271,
    "mq_timedreceive": 4274,
    "mq_timedreceive_time64": 4419,
    "mq_timedsend": 4273,
    "mq_timedsend_time64": 4418,
    "mq_unlink": 4272,
    "mremap": 4167,
    "msgctl": 4402,
    "msgget": 4399,
    "msgrcv": 4401,
    "msgsnd": 4400,
    "msync": 4144,
    "munlock": 4155,
    "munlockall": 4157,
    "munmap": 4091,
    "name_to_handle_at": 4339,
    "nanosleep": 4166,
    "nfsservctl": 4189,
    "nice": 4034,
    "open": 4005,
    "open_by_handle_at": 4340,
    "open_tree": 4428,
    "openat": 4288,
    "openat2": 4437,
    "pause": 4029,
    "perf_event_open": 4333,
    "personality": 4136,
    "pidfd_getfd": 4438,
    "pidfd_open": 4434,
    "pidfd_send_signal": 4424,
    "pipe": 4042,
    "pipe2": 4328,
    "pivot_root": 4216,
    "pkey_alloc": 4364,
    "pkey_free": 4365,
    "pkey_mprotect": 4363,
    "poll": 4188,
    "ppoll": 4302,
    "ppoll_time64": 4414,
    "prctl": 4192,
    "pread64": 4200,
    "preadv": 4330,
    "preadv2": 4361,
    "prlimit64": 4338,
    "process_madvise": 4440,
    "process_mrelease": 4448,
    "process_vm_readv": 4345,
    "process_vm_writev": 4346,
    "pselect6": 4301,
    "pselect6_time64": 4413,
    "ptrace": 4026,
    "pwrite64": 4201,
    "pwritev": 4331,
    "pwritev2": 4362,
    "query_module": 4187,
    "quotactl": 4131,
    "quotactl_fd": 4443,
    "read": 4003,
    "readahead": 4223,
    "readdir": 4089,
    "readlink": 4085,
    "readlinkat": 4298,
    "readv": 4145,
    "reboot": 4088,
    "recv": 4175,
    "recvfrom": 4176,
    "recvmmsg": 4335,
    "recvmmsg_time64": 4417,
    "recvmsg": 4177,
    "remap_file_pages": 4251,
    "removexattr": 4233,
    "rename": 4038,
    "renameat": 4295,
    "renameat2": 4351,
    "request_key": 4281,
    "restart_syscall": 4253,
    "rmdir": 4040,
    "rseq": 4367,
    "rt_sigaction": 4194,
    "rt_sigpending": 4196,
    "rt_sigprocmask": 4195,
    "rt_sigqueueinfo": 4198,
    "rt_sigreturn": 4193,
    "rt_sigsuspend": 4199,
    "rt_sigtimedwait": 4197,
    "rt_sigtimedwait_time64": 4421,
    "rt_tgsigqueueinfo": 4332,
    "sched_get_priority_max": 4163,
    "sched_get_priority_min": 4164,
    "sched_getaffinity": 4240,
    "sched_getattr": 4350,
    "sched_getparam": 4159,
    "sched_getscheduler": 4161,
    "sched_rr_get_interval": 4165,
    "sched_rr_get_interval_time64": 4423,
    "sched_setaffinity": 4239,
    "sched_setattr": 4349,
    "sched_setparam": 4158,
    "sched_setscheduler": 4160,
    "sched_yield": 4162,
    "seccomp": 4352,
    "semctl": 4394,
    "semget": 4393,
    "semtimedop_time64": 4420,
    "send": 4178,
    "sendfile": 4207,
    "sendfile64": 4237,
    "sendmmsg": 4343,
    "sendmsg": 4179,
    "sendto": 4180,
    "set_mempolicy": 4270,
    "set_robust_list": 4309,
    "set_thread_area": 4283,
    "set_tid_address": 4252,
    "setdomainname": 4121,
    "setfsgid": 4139,
    "setfsuid": 4138,
    "setgid": 4046,
    "setgroups": 4081,
    "sethostname": 4074,
    "setitimer": 4104,
    "setns": 4344,
    "setpgid": 4057,
    "setpriority": 4097,
    "setregid": 4071,
    "setresgid": 4190,
    "setresuid": 4185,
    "setreuid": 4070,
    "setrlimit": 4075,
    "setsid": 4066,
    "setsockopt": 4181,
    "settimeofday": 4079,
    "setuid": 4023,
    "setxattr": 4224,
    "sgetmask": 4068,
    "shmat": 4397,
    "shmctl": 4396,
    "shmdt": 4398,
    "shmget": 4395,
    "shutdown": 4182,
    "sigaction": 4067,
    "sigaltstack": 4206,
    "signal": 4048,
    "signalfd": 4317,
    "signalfd4": 4324,
    "sigpending": 4073,
    "sigprocmask": 4126,
    "sigreturn": 4119,
    "sigsuspend": 4072,
    "socket": 4183,
    "socketcall": 4102,
    "socketpair": 4184,
    "splice": 4304,
    "ssetmask": 4069,
    "stat": 4106,
    "stat64": 4213,
    "statfs": 4099,
    "statfs64": 4255,
    "statx": 4366,
    "stime": 4025,
    "swapoff": 4115,
    "swapon": 4087,
    "symlink": 4083,
    "symlinkat": 4297,
    "sync": 4036,
    "sync_file_range": 4305,
    "syncfs": 4342,
    "syscall": 4000,
    "sysfs": 4135,
    "sysinfo": 4116,
    "syslog": 4103,
    "sysmips": 4149,
    "tee": 4306,
    "tgkill": 4266,
    "time": 4013,
    "timer_create": 4257,
    "timer_delete": 4261,
    "timer_getoverrun": 4260,
    "timer_gettime": 4259,
    "timer_gettime64": 4408,
    "timer_settime": 4258,
    "timer_settime64": 4409,
    "timerfd": 4318,
    "timerfd_create": 4321,
    "timerfd_gettime": 4322,
    "timerfd_gettime64": 4410,
    "timerfd_settime": 4323,
    "timerfd_settime64": 4411,
    "times": 4043,
    "tkill": 4236,
    "truncate": 4092,
    "truncate64": 4211,
    "umask": 4060,
    "umount": 4022,
    "umount2": 4052,
    "uname": 4122,
    "unlink": 4010,
    "unlinkat": 4294,
    "unshare": 4303,
    "uselib": 4086,
    "userfaultfd": 4357,
    "ustat": 4062,
    "utime": 4030,
    "utimensat": 4316,
    "utimensat_time64": 4412,
    "utimes": 4267,
    "vhangup": 4111,
    "vm86": 4113,
    "vmsplice": 4307,
    "wait4": 4114,
    "waitid": 4278,
    "waitpid": 4007,
    "write": 4004,
    "writev": 4146,
}



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_powerpc64 = {
    "_llseek": 140,
    "_newselect": 142,
    "_sysctl": 149,
    "accept": 330,
    "accept4": 344,
    "access": 33,
    "acct": 51,
    "add_key": 269,
    "adjtimex": 124,
    "alarm": 27,
    "bdflush": 134,
    "bind": 327,
    "bpf": 361,
    "brk": 45,
    "capget": 183,
    "capset": 184,
    "chdir": 12,
    "chmod": 15,
    "chown": 181,
    "chroot": 61,
    "clock_adjtime": 347,
    "clock_getres": 247,
    "clock_gettime": 246,
    "clock_nanosleep": 248,
    "clock_settime": 245,
    "clone": 120,
    "clone3": 435,
    "close": 6,
    "close_range": 436,
    "connect": 328,
    "copy_file_range": 379,
    "creat": 8,
    "create_module": 127,
    "delete_module": 129,
    "dup": 41,
    "dup2": 63,
    "dup3": 316,
    "epoll_create": 236,
    "epoll_create1": 315,
    "epoll_ctl": 237,
    "epoll_pwait": 303,
    "epoll_pwait2": 441,
    "epoll_wait": 238,
    "eventfd": 307,
    "eventfd2": 314,
    "execve": 11,
    "execveat": 362,
    "exit": 1,
    "exit_group": 234,
    "faccessat": 298,
    "faccessat2": 439,
    "fadvise64": 233,
    "fallocate": 309,
    "fanotify_init": 323,
    "fanotify_mark": 324,
    "fchdir": 133,
    "fchmod": 94,
    "fchmodat": 297,
    "fchown": 95,
    "fchownat": 289,
    "fcntl": 55,
    "fdatasync": 148,
    "fgetxattr": 214,
    "finit_module": 353,
    "flistxattr": 217,
    "flock": 143,
    "fork": 2,
    "fremovexattr": 220,
    "fsconfig": 431,
    "fsetxattr": 211,
    "fsmount": 432,
    "fsopen": 430,
    "fspick": 433,
    "fstat": 108,
    "fstatfs": 100,
    "fstatfs64": 253,
    "fsync": 118,
    "ftruncate": 93,
    "futex": 221,
    "futimesat": 290,
    "get_kernel_syms": 130,
    "get_mempolicy": 260,
    "get_robust_list": 299,
    "getcpu": 302,
    "getcwd": 182,
    "getdents": 141,
    "getdents64": 202,
    "getegid": 50,
    "geteuid": 49,
    "getgid": 47,
    "getgroups": 80,
    "getitimer": 105,
    "getpeername": 332,
    "getpgid": 132,
    "getpgrp": 65,
    "getpid": 20,
    "getpmsg": 187,
    "getppid": 64,
    "getpriority": 96,
    "getrandom": 359,
    "getresgid": 170,
    "getresuid": 165,
    "getrlimit": 76,
    "getrusage": 77,
    "getsid": 147,
    "getsockname": 331,
    "getsockopt": 340,
    "gettid": 207,
    "gettimeofday": 78,
    "getuid": 24,
    "getxattr": 212,
    "idle": 112,
    "init_module": 128,
    "inotify_add_watch": 276,
    "inotify_init": 275,
    "inotify_init1": 318,
    "inotify_rm_watch": 277,
    "io_cancel": 231,
    "io_destroy": 228,
    "io_getevents": 229,
    "io_pgetevents": 388,
    "io_setup": 227,
    "io_submit": 230,
    "io_uring_enter": 426,
    "io_uring_register": 427,
    "io_uring_setup": 425,
    "ioctl": 54,
    "ioperm": 101,
    "iopl": 110,
    "ioprio_get": 274,
    "ioprio_set": 273,
    "ipc": 117,
    "kcmp": 354,
    "kexec_file_load": 382,
    "kexec_load": 268,
    "keyctl": 271,
    "kill": 37,
    "landlock_add_rule": 445,
    "landlock_create_ruleset": 444,
    "landlock_restrict_self": 446,
    "lchown": 16,
    "lgetxattr": 213,
    "link": 9,
    "linkat": 294,
    "listen": 329,
    "listxattr": 215,
    "llistxattr": 216,
    "lookup_dcookie": 235,
    "lremovexattr": 219,
    "lseek": 19,
    "lsetxattr": 210,
    "lstat": 107,
    "madvise": 205,
    "mbind": 259,
    "membarrier": 365,
    "memfd_create": 360,
    "migrate_pages": 258,
    "mincore": 206,
    "mkdir": 39,
    "mkdirat": 287,
    "mknod": 14,
    "mknodat": 288,
    "mlock": 150,
    "mlock2": 378,
    "mlockall": 152,
    "mmap": 90,
    "modify_ldt": 123,
    "mount": 21,
    "mount_setattr": 442,
    "move_mount": 429,
    "move_pages": 301,
    "mprotect": 125,
    "mq_getsetattr": 267,
    "mq_notify": 266,
    "mq_open": 262,
    "mq_timedreceive": 265,
    "mq_timedsend": 264,
    "mq_unlink": 263,
    "mremap": 163,
    "msgctl": 402,
    "msgget": 399,
    "msgrcv": 401,
    "msgsnd": 400,
    "msync": 144,
    "multiplexer": 201,
    "munlock": 151,
    "munlockall": 153,
    "munmap": 91,
    "name_to_handle_at": 345,
    "nanosleep": 162,
    "newfstatat": 291,
    "nfsservctl": 168,
    "nice": 34,
    "oldfstat": 28,
    "oldlstat": 84,
    "oldolduname": 59,
    "oldstat": 18,
    "olduname": 109,
    "open": 5,
    "open_by_handle_at": 346,
    "open_tree": 428,
    "openat": 286,
    "openat2": 437,
    "pause": 29,
    "pciconfig_iobase": 200,
    "pciconfig_read": 198,
    "pciconfig_write": 199,
    "perf_event_open": 319,
    "personality": 136,
    "pidfd_getfd": 438,
    "pidfd_open": 434,
    "pidfd_send_signal": 424,
    "pipe": 42,
    "pipe2": 317,
    "pivot_root": 203,
    "pkey_alloc": 384,
    "pkey_free": 385,
    "pkey_mprotect": 386,
    "poll": 167,
    "ppoll": 281,
    "prctl": 171,
    "pread64": 179,
    "preadv": 320,
    "preadv2": 380,
    "prlimit64": 325,
    "process_madvise": 440,
    "process_mrelease": 448,
    "process_vm_readv": 351,
    "process_vm_writev": 352,
    "pselect6": 280,
    "ptrace": 26,
    "pwrite64": 180,
    "pwritev": 321,
    "pwritev2": 381,
    "query_module": 166,
    "quotactl": 131,
    "quotactl_fd": 443,
    "read": 3,
    "readahead": 191,
    "readdir": 89,
    "readlink": 85,
    "readlinkat": 296,
    "readv": 145,
    "reboot": 88,
    "recv": 336,
    "recvfrom": 337,
    "recvmmsg": 343,
    "recvmsg": 342,
    "remap_file_pages": 239,
    "removexattr": 218,
    "rename": 38,
    "renameat": 293,
    "renameat2": 357,
    "request_key": 270,
    "restart_syscall": 0,
    "rmdir": 40,
    "rseq": 387,
    "rt_sigaction": 173,
    "rt_sigpending": 175,
    "rt_sigprocmask": 174,
    "rt_sigqueueinfo": 177,
    "rt_sigreturn": 172,
    "rt_sigsuspend": 178,
    "rt_sigtimedwait": 176,
    "rt_tgsigqueueinfo": 322,
    "rtas": 255,
    "sched_get_priority_max": 159,
    "sched_get_priority_min": 160,
    "sched_getaffinity": 223,
    "sched_getattr": 356,
    "sched_getparam": 155,
    "sched_getscheduler": 157,
    "sched_rr_get_interval": 161,
    "sched_setaffinity": 222,
    "sched_setattr": 355,
    "sched_setparam": 154,
    "sched_setscheduler": 156,
    "sched_yield": 158,
    "seccomp": 358,
    "select": 82,
    "semctl": 394,
    "semget": 393,
    "semtimedop": 392,
    "send": 334,
    "sendfile": 186,
    "sendmmsg": 349,
    "sendmsg": 341,
    "sendto": 335,
    "set_mempolicy": 261,
    "set_robust_list": 300,
    "set_tid_address": 232,
    "setdomainname": 121,
    "setfsgid": 139,
    "setfsuid": 138,
    "setgid": 46,
    "setgroups": 81,
    "sethostname": 74,
    "setitimer": 104,
    "setns": 350,
    "setpgid": 57,
    "setpriority": 97,
    "setregid": 71,
    "setresgid": 169,
    "setresuid": 164,
    "setreuid": 70,
    "setrlimit": 75,
    "setsid": 66,
    "setsockopt": 339,
    "settimeofday": 79,
    "setuid": 23,
    "setxattr": 209,
    "sgetmask": 68,
    "shmat": 397,
    "shmctl": 396,
    "shmdt": 398,
    "shmget": 395,
    "shutdown": 338,
    "sigaction": 67,
    "sigaltstack": 185,
    "signal": 48,
    "signalfd": 305,
    "signalfd4": 313,
    "sigpending": 73,
    "sigprocmask": 126,
    "sigreturn": 119,
    "sigsuspend": 72,
    "socket": 326,
    "socketcall": 102,
    "socketpair": 333,
    "splice": 283,
    "spu_create": 279,
    "spu_run": 278,
    "ssetmask": 69,
    "stat": 106,
    "statfs": 99,
    "statfs64": 252,
    "statx": 383,
    "stime": 25,
    "subpage_prot": 310,
    "swapcontext": 249,
    "swapoff": 115,
    "swapon": 87,
    "switch_endian": 363,
    "symlink": 83,
    "symlinkat": 295,
    "sync": 36,
    "sync_file_range2": 308,
    "syncfs": 348,
    "sys_debug_setcontext": 256,
    "sysfs": 135,
    "sysinfo": 116,
    "syslog": 103,
    "tee": 284,
    "tgkill": 250,
    "time": 13,
    "timer_create": 240,
    "timer_delete": 244,
    "timer_getoverrun": 243,
    "timer_gettime": 242,
    "timer_settime": 241,
    "timerfd_create": 306,
    "timerfd_gettime": 312,
    "timerfd_settime": 311,
    "times": 43,
    "tkill": 208,
    "truncate": 92,
    "ugetrlimit": 190,
    "umask": 60,
    "umount": 22,
    "umount2": 52,
    "uname": 122,
    "unlink": 10,
    "unlinkat": 292,
    "unshare": 282,
    "uselib": 86,
    "userfaultfd": 364,
    "ustat": 62,
    "utime": 30,
    "utimensat": 304,
    "utimes": 251,
    "vfork": 189,
    "vhangup": 111,
    "vm86": 113,
    "vmsplice": 285,
    "wait4": 114,
    "waitid": 272,
    "waitpid": 7,
    "write": 4,
    "writev": 146,
}



#!/usr/bin/python3

syscalls_names = [
    "_llseek",
    "_newselect",
    "_sysctl",
    "accept",
    "accept4",
    "access",
    "acct",
    "add_key",
    "adjtimex",
    "alarm",
    "arc_gettls",
    "arc_settls",
    "arc_usr_cmpxchg",
    "arch_prctl",
    "arm_fadvise64_64",
    "atomic_barrier",
    "atomic_cmpxchg_32",
    "bdflush",
    "bind",
    "bpf",
    "brk",
    "cachectl",
    "cacheflush",
    "capget",
    "capset",
    "chdir",
    "chmod",
    "chown",
    "chown32",
    "chroot",
    "clock_adjtime",
    "clock_adjtime64",
    "clock_getres",
    "clock_getres_time64",
    "clock_gettime",
    "clock_gettime64",
    "clock_nanosleep",
    "clock_nanosleep_time64",
    "clock_settime",
    "clock_settime64",
    "clone",
    "clone2",
    "clone3",
    "close",
    "close_range",
    "connect",
    "copy_file_range",
    "creat",
    "create_module",
    "delete_module",
    "dipc",
    "dup",
    "dup2",
    "dup3",
    "epoll_create",
    "epoll_create1",
    "epoll_ctl",
    "epoll_ctl_old",
    "epoll_pwait",
    "epoll_pwait2",
    "epoll_wait",
    "epoll_wait_old",
    "eventfd",
    "eventfd2",
    "exec_with_loader",
    "execv",
    "execve",
    "execveat",
    "exit",
    "exit_group",
    "faccessat",
    "faccessat2",
    "fadvise64",
    "fadvise64_64",
    "fallocate",
    "fanotify_init",
    "fanotify_mark",
    "fchdir",
    "fchmod",
    "fchmodat",
    "fchown",
    "fchown32",
    "fchownat",
    "fcntl",
    "fcntl64",
    "fdatasync",
    "fgetxattr",
    "finit_module",
    "flistxattr",
    "flock",
    "fork",
    "fp_udfiex_crtl",
    "fremovexattr",
    "fsconfig",
    "fsetxattr",
    "fsmount",
    "fsopen",
    "fspick",
    "fstat",
    "fstat64",
    "fstatat64",
    "fstatfs",
    "fstatfs64",
    "fsync",
    "ftruncate",
    "ftruncate64",
    "futex",
    "futex_time64",
    "futimesat",
    "get_kernel_syms",
    "get_mempolicy",
    "get_robust_list",
    "get_thread_area",
    "getcpu",
    "getcwd",
    "getdents",
    "getdents64",
    "getdomainname",
    "getdtablesize",
    "getegid",
    "getegid32",
    "geteuid",
    "geteuid32",
    "getgid",
    "getgid32",
    "getgroups",
    "getgroups32",
    "gethostname",
    "getitimer",
    "getpagesize",
    "getpeername",
    "getpgid",
    "getpgrp",
    "getpid",
    "getpmsg",
    "getppid",
    "getpriority",
    "getrandom",
    "getresgid",
    "getresgid32",
    "getresuid",
    "getresuid32",
    "getrlimit",
    "getrusage",
    "getsid",
    "getsockname",
    "getsockopt",
    "gettid",
    "gettimeofday",
    "getuid",
    "getuid32",
    "getunwind",
    "getxattr",
    "getxgid",
    "getxpid",
    "getxuid",
    "idle",
    "init_module",
    "inotify_add_watch",
    "inotify_init",
    "inotify_init1",
    "inotify_rm_watch",
    "io_cancel",
    "io_destroy",
    "io_getevents",
    "io_pgetevents",
    "io_pgetevents_time64",
    "io_setup",
    "io_submit",
    "io_uring_enter",
    "io_uring_register",
    "io_uring_setup",
    "ioctl",
    "ioperm",
    "iopl",
    "ioprio_get",
    "ioprio_set",
    "ipc",
    "kcmp",
    "kern_features",
    "kexec_file_load",
    "kexec_load",
    "keyctl",
    "kill",
    "landlock_add_rule",
    "landlock_create_ruleset",
    "landlock_restrict_self",
    "lchown",
    "lchown32",
    "lgetxattr",
    "link",
    "linkat",
    "listen",
    "listxattr",
    "llistxattr",
    "lookup_dcookie",
    "lremovexattr",
    "lseek",
    "lsetxattr",
    "lstat",
    "lstat64",
    "madvise",
    "mbind",
    "membarrier",
    "memfd_create",
    "memfd_secret",
    "memory_ordering",
    "migrate_pages",
    "mincore",
    "mkdir",
    "mkdirat",
    "mknod",
    "mknodat",
    "mlock",
    "mlock2",
    "mlockall",
    "mmap",
    "mmap2",
    "modify_ldt",
    "mount",
    "mount_setattr",
    "move_mount",
    "move_pages",
    "mprotect",
    "mq_getsetattr",
    "mq_notify",
    "mq_open",
    "mq_timedreceive",
    "mq_timedreceive_time64",
    "mq_timedsend",
    "mq_timedsend_time64",
    "mq_unlink",
    "mremap",
    "msgctl",
    "msgget",
    "msgrcv",
    "msgsnd",
    "msync",
    "multiplexer",
    "munlock",
    "munlockall",
    "munmap",
    "name_to_handle_at",
    "nanosleep",
    "newfstatat",
    "nfsservctl",
    "nice",
    "old_adjtimex",
    "old_getpagesize",
    "oldfstat",
    "oldlstat",
    "oldolduname",
    "oldstat",
    "oldumount",
    "olduname",
    "open",
    "open_by_handle_at",
    "open_tree",
    "openat",
    "openat2",
    "or1k_atomic",
    "osf_adjtime",
    "osf_afs_syscall",
    "osf_alt_plock",
    "osf_alt_setsid",
    "osf_alt_sigpending",
    "osf_asynch_daemon",
    "osf_audcntl",
    "osf_audgen",
    "osf_chflags",
    "osf_execve",
    "osf_exportfs",
    "osf_fchflags",
    "osf_fdatasync",
    "osf_fpathconf",
    "osf_fstat",
    "osf_fstatfs",
    "osf_fstatfs64",
    "osf_fuser",
    "osf_getaddressconf",
    "osf_getdirentries",
    "osf_getdomainname",
    "osf_getfh",
    "osf_getfsstat",
    "osf_gethostid",
    "osf_getitimer",
    "osf_getlogin",
    "osf_getmnt",
    "osf_getrusage",
    "osf_getsysinfo",
    "osf_gettimeofday",
    "osf_kloadcall",
    "osf_kmodcall",
    "osf_lstat",
    "osf_memcntl",
    "osf_mincore",
    "osf_mount",
    "osf_mremap",
    "osf_msfs_syscall",
    "osf_msleep",
    "osf_mvalid",
    "osf_mwakeup",
    "osf_naccept",
    "osf_nfssvc",
    "osf_ngetpeername",
    "osf_ngetsockname",
    "osf_nrecvfrom",
    "osf_nrecvmsg",
    "osf_nsendmsg",
    "osf_ntp_adjtime",
    "osf_ntp_gettime",
    "osf_old_creat",
    "osf_old_fstat",
    "osf_old_getpgrp",
    "osf_old_killpg",
    "osf_old_lstat",
    "osf_old_open",
    "osf_old_sigaction",
    "osf_old_sigblock",
    "osf_old_sigreturn",
    "osf_old_sigsetmask",
    "osf_old_sigvec",
    "osf_old_stat",
    "osf_old_vadvise",
    "osf_old_vtrace",
    "osf_old_wait",
    "osf_oldquota",
    "osf_pathconf",
    "osf_pid_block",
    "osf_pid_unblock",
    "osf_plock",
    "osf_priocntlset",
    "osf_profil",
    "osf_proplist_syscall",
    "osf_reboot",
    "osf_revoke",
    "osf_sbrk",
    "osf_security",
    "osf_select",
    "osf_set_program_attributes",
    "osf_set_speculative",
    "osf_sethostid",
    "osf_setitimer",
    "osf_setlogin",
    "osf_setsysinfo",
    "osf_settimeofday",
    "osf_shmat",
    "osf_signal",
    "osf_sigprocmask",
    "osf_sigsendset",
    "osf_sigstack",
    "osf_sigwaitprim",
    "osf_sstk",
    "osf_stat",
    "osf_statfs",
    "osf_statfs64",
    "osf_subsys_info",
    "osf_swapctl",
    "osf_swapon",
    "osf_syscall",
    "osf_sysinfo",
    "osf_table",
    "osf_uadmin",
    "osf_usleep_thread",
    "osf_uswitch",
    "osf_utc_adjtime",
    "osf_utc_gettime",
    "osf_utimes",
    "osf_utsname",
    "osf_wait4",
    "osf_waitid",
    "pause",
    "pciconfig_iobase",
    "pciconfig_read",
    "pciconfig_write",
    "perf_event_open",
    "perfctr",
    "personality",
    "pidfd_getfd",
    "pidfd_open",
    "pidfd_send_signal",
    "pipe",
    "pipe2",
    "pivot_root",
    "pkey_alloc",
    "pkey_free",
    "pkey_mprotect",
    "poll",
    "ppoll",
    "ppoll_time64",
    "prctl",
    "pread64",
    "preadv",
    "preadv2",
    "prlimit64",
    "process_madvise",
    "process_mrelease",
    "process_vm_readv",
    "process_vm_writev",
    "pselect6",
    "pselect6_time64",
    "ptrace",
    "pwrite64",
    "pwritev",
    "pwritev2",
    "query_module",
    "quotactl",
    "quotactl_fd",
    "read",
    "readahead",
    "readdir",
    "readlink",
    "readlinkat",
    "readv",
    "reboot",
    "recv",
    "recvfrom",
    "recvmmsg",
    "recvmmsg_time64",
    "recvmsg",
    "remap_file_pages",
    "removexattr",
    "rename",
    "renameat",
    "renameat2",
    "request_key",
    "restart_syscall",
    "riscv_flush_icache",
    "rmdir",
    "rseq",
    "rt_sigaction",
    "rt_sigpending",
    "rt_sigprocmask",
    "rt_sigqueueinfo",
    "rt_sigreturn",
    "rt_sigsuspend",
    "rt_sigtimedwait",
    "rt_sigtimedwait_time64",
    "rt_tgsigqueueinfo",
    "rtas",
    "s390_guarded_storage",
    "s390_pci_mmio_read",
    "s390_pci_mmio_write",
    "s390_runtime_instr",
    "s390_sthyi",
    "sched_get_affinity",
    "sched_get_priority_max",
    "sched_get_priority_min",
    "sched_getaffinity",
    "sched_getattr",
    "sched_getparam",
    "sched_getscheduler",
    "sched_rr_get_interval",
    "sched_rr_get_interval_time64",
    "sched_set_affinity",
    "sched_setaffinity",
    "sched_setattr",
    "sched_setparam",
    "sched_setscheduler",
    "sched_yield",
    "seccomp",
    "select",
    "semctl",
    "semget",
    "semop",
    "semtimedop",
    "semtimedop_time64",
    "send",
    "sendfile",
    "sendfile64",
    "sendmmsg",
    "sendmsg",
    "sendto",
    "set_mempolicy",
    "set_robust_list",
    "set_thread_area",
    "set_tid_address",
    "setdomainname",
    "setfsgid",
    "setfsgid32",
    "setfsuid",
    "setfsuid32",
    "setgid",
    "setgid32",
    "setgroups",
    "setgroups32",
    "sethae",
    "sethostname",
    "setitimer",
    "setns",
    "setpgid",
    "setpgrp",
    "setpriority",
    "setregid",
    "setregid32",
    "setresgid",
    "setresgid32",
    "setresuid",
    "setresuid32",
    "setreuid",
    "setreuid32",
    "setrlimit",
    "setsid",
    "setsockopt",
    "settimeofday",
    "setuid",
    "setuid32",
    "setxattr",
    "sgetmask",
    "shmat",
    "shmctl",
    "shmdt",
    "shmget",
    "shutdown",
    "sigaction",
    "sigaltstack",
    "signal",
    "signalfd",
    "signalfd4",
    "sigpending",
    "sigprocmask",
    "sigreturn",
    "sigsuspend",
    "socket",
    "socketcall",
    "socketpair",
    "splice",
    "spu_create",
    "spu_run",
    "ssetmask",
    "stat",
    "stat64",
    "statfs",
    "statfs64",
    "statx",
    "stime",
    "subpage_prot",
    "swapcontext",
    "swapoff",
    "swapon",
    "switch_endian",
    "symlink",
    "symlinkat",
    "sync",
    "sync_file_range",
    "sync_file_range2",
    "syncfs",
    "sys_debug_setcontext",
    "syscall",
    "sysfs",
    "sysinfo",
    "syslog",
    "sysmips",
    "tee",
    "tgkill",
    "time",
    "timer_create",
    "timer_delete",
    "timer_getoverrun",
    "timer_gettime",
    "timer_gettime64",
    "timer_settime",
    "timer_settime64",
    "timerfd",
    "timerfd_create",
    "timerfd_gettime",
    "timerfd_gettime64",
    "timerfd_settime",
    "timerfd_settime64",
    "times",
    "tkill",
    "truncate",
    "truncate64",
    "ugetrlimit",
    "umask",
    "umount",
    "umount2",
    "uname",
    "unlink",
    "unlinkat",
    "unshare",
    "uselib",
    "userfaultfd",
    "ustat",
    "utime",
    "utimensat",
    "utimensat_time64",
    "utimes",
    "utrap_install",
    "vfork",
    "vhangup",
    "vm86",
    "vm86old",
    "vmsplice",
    "wait4",
    "waitid",
    "waitpid",
    "write",
    "writev",
]



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_ia64 = {
    "_sysctl": 1150,
    "accept": 1194,
    "accept4": 1334,
    "access": 1049,
    "acct": 1064,
    "add_key": 1271,
    "adjtimex": 1131,
    "bdflush": 1138,
    "bind": 1191,
    "bpf": 1341,
    "brk": 1060,
    "capget": 1185,
    "capset": 1186,
    "chdir": 1034,
    "chmod": 1038,
    "chown": 1039,
    "chroot": 1068,
    "clock_adjtime": 1328,
    "clock_getres": 1255,
    "clock_gettime": 1254,
    "clock_nanosleep": 1256,
    "clock_settime": 1253,
    "clone": 1128,
    "clone2": 1213,
    "close": 1029,
    "close_range": 1460,
    "connect": 1192,
    "copy_file_range": 1347,
    "creat": 1030,
    "delete_module": 1134,
    "dup": 1057,
    "dup2": 1070,
    "dup3": 1316,
    "epoll_create": 1243,
    "epoll_create1": 1315,
    "epoll_ctl": 1244,
    "epoll_pwait": 1305,
    "epoll_pwait2": 1465,
    "epoll_wait": 1245,
    "eventfd": 1309,
    "eventfd2": 1314,
    "execve": 1033,
    "execveat": 1342,
    "exit": 1025,
    "exit_group": 1236,
    "faccessat": 1293,
    "faccessat2": 1463,
    "fadvise64": 1234,
    "fallocate": 1303,
    "fanotify_init": 1323,
    "fanotify_mark": 1324,
    "fchdir": 1035,
    "fchmod": 1099,
    "fchmodat": 1292,
    "fchown": 1100,
    "fchownat": 1284,
    "fcntl": 1066,
    "fdatasync": 1052,
    "fgetxattr": 1222,
    "finit_module": 1335,
    "flistxattr": 1225,
    "flock": 1145,
    "fremovexattr": 1228,
    "fsconfig": 1455,
    "fsetxattr": 1219,
    "fsmount": 1456,
    "fsopen": 1454,
    "fspick": 1457,
    "fstat": 1212,
    "fstatfs": 1104,
    "fstatfs64": 1257,
    "fsync": 1051,
    "ftruncate": 1098,
    "futex": 1230,
    "futimesat": 1285,
    "get_mempolicy": 1260,
    "get_robust_list": 1299,
    "getcpu": 1304,
    "getcwd": 1184,
    "getdents": 1144,
    "getdents64": 1214,
    "getegid": 1063,
    "geteuid": 1047,
    "getgid": 1062,
    "getgroups": 1077,
    "getitimer": 1119,
    "getpeername": 1196,
    "getpgid": 1079,
    "getpid": 1041,
    "getpmsg": 1188,
    "getppid": 1042,
    "getpriority": 1101,
    "getrandom": 1339,
    "getresgid": 1075,
    "getresuid": 1073,
    "getrlimit": 1085,
    "getrusage": 1086,
    "getsid": 1082,
    "getsockname": 1195,
    "getsockopt": 1204,
    "gettid": 1105,
    "gettimeofday": 1087,
    "getuid": 1046,
    "getunwind": 1215,
    "getxattr": 1220,
    "init_module": 1133,
    "inotify_add_watch": 1278,
    "inotify_init": 1277,
    "inotify_init1": 1318,
    "inotify_rm_watch": 1279,
    "io_cancel": 1242,
    "io_destroy": 1239,
    "io_getevents": 1240,
    "io_pgetevents": 1351,
    "io_setup": 1238,
    "io_submit": 1241,
    "io_uring_enter": 1450,
    "io_uring_register": 1451,
    "io_uring_setup": 1449,
    "ioctl": 1065,
    "ioprio_get": 1275,
    "ioprio_set": 1274,
    "kcmp": 1345,
    "kexec_load": 1268,
    "keyctl": 1273,
    "kill": 1053,
    "landlock_add_rule": 1469,
    "landlock_create_ruleset": 1468,
    "landlock_restrict_self": 1470,
    "lchown": 1124,
    "lgetxattr": 1221,
    "link": 1031,
    "linkat": 1289,
    "listen": 1193,
    "listxattr": 1223,
    "llistxattr": 1224,
    "lookup_dcookie": 1237,
    "lremovexattr": 1227,
    "lseek": 1040,
    "lsetxattr": 1218,
    "lstat": 1211,
    "madvise": 1209,
    "mbind": 1259,
    "membarrier": 1344,
    "memfd_create": 1340,
    "migrate_pages": 1280,
    "mincore": 1208,
    "mkdir": 1055,
    "mkdirat": 1282,
    "mknod": 1037,
    "mknodat": 1283,
    "mlock": 1153,
    "mlock2": 1346,
    "mlockall": 1154,
    "mmap": 1151,
    "mmap2": 1172,
    "mount": 1043,
    "mount_setattr": 1466,
    "move_mount": 1453,
    "move_pages": 1276,
    "mprotect": 1155,
    "mq_getsetattr": 1267,
    "mq_notify": 1266,
    "mq_open": 1262,
    "mq_timedreceive": 1265,
    "mq_timedsend": 1264,
    "mq_unlink": 1263,
    "mremap": 1156,
    "msgctl": 1112,
    "msgget": 1109,
    "msgrcv": 1111,
    "msgsnd": 1110,
    "msync": 1157,
    "munlock": 1158,
    "munlockall": 1159,
    "munmap": 1152,
    "name_to_handle_at": 1326,
    "nanosleep": 1168,
    "newfstatat": 1286,
    "nfsservctl": 1169,
    "old_getpagesize": 1171,
    "open": 1028,
    "open_by_handle_at": 1327,
    "open_tree": 1452,
    "openat": 1281,
    "openat2": 1461,
    "pciconfig_read": 1173,
    "pciconfig_write": 1174,
    "perf_event_open": 1352,
    "personality": 1140,
    "pidfd_getfd": 1462,
    "pidfd_open": 1458,
    "pidfd_send_signal": 1448,
    "pipe": 1058,
    "pipe2": 1317,
    "pivot_root": 1207,
    "pkey_alloc": 1355,
    "pkey_free": 1356,
    "pkey_mprotect": 1354,
    "poll": 1090,
    "ppoll": 1295,
    "prctl": 1170,
    "pread64": 1148,
    "preadv": 1319,
    "preadv2": 1348,
    "prlimit64": 1325,
    "process_madvise": 1464,
    "process_mrelease": 1472,
    "process_vm_readv": 1332,
    "process_vm_writev": 1333,
    "pselect6": 1294,
    "ptrace": 1048,
    "pwrite64": 1149,
    "pwritev": 1320,
    "pwritev2": 1349,
    "quotactl": 1137,
    "quotactl_fd": 1467,
    "read": 1026,
    "readahead": 1216,
    "readlink": 1092,
    "readlinkat": 1291,
    "readv": 1146,
    "reboot": 1096,
    "recv": 1200,
    "recvfrom": 1201,
    "recvmmsg": 1322,
    "recvmsg": 1206,
    "remap_file_pages": 1125,
    "removexattr": 1226,
    "rename": 1054,
    "renameat": 1288,
    "renameat2": 1338,
    "request_key": 1272,
    "restart_syscall": 1246,
    "rmdir": 1056,
    "rseq": 1357,
    "rt_sigaction": 1177,
    "rt_sigpending": 1178,
    "rt_sigprocmask": 1179,
    "rt_sigqueueinfo": 1180,
    "rt_sigreturn": 1181,
    "rt_sigsuspend": 1182,
    "rt_sigtimedwait": 1183,
    "rt_tgsigqueueinfo": 1321,
    "sched_get_priority_max": 1165,
    "sched_get_priority_min": 1166,
    "sched_getaffinity": 1232,
    "sched_getattr": 1337,
    "sched_getparam": 1160,
    "sched_getscheduler": 1162,
    "sched_rr_get_interval": 1167,
    "sched_setaffinity": 1231,
    "sched_setattr": 1336,
    "sched_setparam": 1161,
    "sched_setscheduler": 1163,
    "sched_yield": 1164,
    "seccomp": 1353,
    "select": 1089,
    "semctl": 1108,
    "semget": 1106,
    "semop": 1107,
    "semtimedop": 1247,
    "send": 1198,
    "sendfile": 1187,
    "sendmmsg": 1331,
    "sendmsg": 1205,
    "sendto": 1199,
    "set_mempolicy": 1261,
    "set_robust_list": 1298,
    "set_tid_address": 1233,
    "setdomainname": 1129,
    "setfsgid": 1143,
    "setfsuid": 1142,
    "setgid": 1061,
    "setgroups": 1078,
    "sethostname": 1083,
    "setitimer": 1118,
    "setns": 1330,
    "setpgid": 1080,
    "setpriority": 1102,
    "setregid": 1072,
    "setresgid": 1076,
    "setresuid": 1074,
    "setreuid": 1071,
    "setrlimit": 1084,
    "setsid": 1081,
    "setsockopt": 1203,
    "settimeofday": 1088,
    "setuid": 1045,
    "setxattr": 1217,
    "shmat": 1114,
    "shmctl": 1116,
    "shmdt": 1115,
    "shmget": 1113,
    "shutdown": 1202,
    "sigaltstack": 1176,
    "signalfd": 1307,
    "signalfd4": 1313,
    "socket": 1190,
    "socketpair": 1197,
    "splice": 1297,
    "stat": 1210,
    "statfs": 1103,
    "statfs64": 1258,
    "statx": 1350,
    "swapoff": 1095,
    "swapon": 1094,
    "symlink": 1091,
    "symlinkat": 1290,
    "sync": 1050,
    "sync_file_range": 1300,
    "syncfs": 1329,
    "sysfs": 1139,
    "sysinfo": 1127,
    "syslog": 1117,
    "tee": 1301,
    "tgkill": 1235,
    "timer_create": 1248,
    "timer_delete": 1252,
    "timer_getoverrun": 1251,
    "timer_gettime": 1250,
    "timer_settime": 1249,
    "timerfd": 1308,
    "timerfd_create": 1310,
    "timerfd_gettime": 1312,
    "timerfd_settime": 1311,
    "times": 1059,
    "tkill": 1229,
    "truncate": 1097,
    "umask": 1067,
    "umount": 1044,
    "umount2": 1044,
    "uname": 1130,
    "unlink": 1032,
    "unlinkat": 1287,
    "unshare": 1296,
    "uselib": 1093,
    "userfaultfd": 1343,
    "ustat": 1069,
    "utimensat": 1306,
    "utimes": 1036,
    "vhangup": 1123,
    "vmsplice": 1302,
    "wait4": 1126,
    "waitid": 1270,
    "write": 1027,
    "writev": 1147,
}



#!/usr/bin/python3

import os

from system_calls.tables.names import syscalls_names
from system_calls.tables.alpha import syscalls_alpha
from system_calls.tables.arc import syscalls_arc
from system_calls.tables.arm64 import syscalls_arm64
from system_calls.tables.armoabi import syscalls_armoabi
from system_calls.tables.arm import syscalls_arm
from system_calls.tables.avr32 import syscalls_avr32
from system_calls.tables.blackfin import syscalls_blackfin
from system_calls.tables.c6x import syscalls_c6x
from system_calls.tables.cris import syscalls_cris
from system_calls.tables.csky import syscalls_csky
from system_calls.tables.frv import syscalls_frv
from system_calls.tables.h8300 import syscalls_h8300
from system_calls.tables.hexagon import syscalls_hexagon
from system_calls.tables.i386 import syscalls_i386
from system_calls.tables.ia64 import syscalls_ia64
from system_calls.tables.m32r import syscalls_m32r
from system_calls.tables.m68k import syscalls_m68k
from system_calls.tables.metag import syscalls_metag
from system_calls.tables.microblaze import syscalls_microblaze
from system_calls.tables.mips64n32 import syscalls_mips64n32
from system_calls.tables.mips64 import syscalls_mips64
from system_calls.tables.mipso32 import syscalls_mipso32
from system_calls.tables.mn10300 import syscalls_mn10300
from system_calls.tables.nds32 import syscalls_nds32
from system_calls.tables.nios2 import syscalls_nios2
from system_calls.tables.openrisc import syscalls_openrisc
from system_calls.tables.parisc import syscalls_parisc
from system_calls.tables.powerpc64 import syscalls_powerpc64
from system_calls.tables.powerpc import syscalls_powerpc
from system_calls.tables.riscv32 import syscalls_riscv32
from system_calls.tables.riscv64 import syscalls_riscv64
from system_calls.tables.s390 import syscalls_s390
from system_calls.tables.s390x import syscalls_s390x
from system_calls.tables.score import syscalls_score
from system_calls.tables.sh64 import syscalls_sh64
from system_calls.tables.sh import syscalls_sh
from system_calls.tables.sparc64 import syscalls_sparc64
from system_calls.tables.sparc import syscalls_sparc
from system_calls.tables.tile64 import syscalls_tile64
from system_calls.tables.tile import syscalls_tile
from system_calls.tables.unicore32 import syscalls_unicore32
from system_calls.tables.x32 import syscalls_x32
from system_calls.tables.x86_64 import syscalls_x86_64
from system_calls.tables.xtensa import syscalls_xtensa


class NoSuchSystemCall(Exception):
    """Exception will be called if asked for not existing system call.
    """
    pass


class NotSupportedSystemCall(Exception):
    """Exception will be called if asked for system call not supported
    on requested architecture.
    """
    pass


class syscalls(dict):
    def __init__(self):
        self.syscalls = {
            'names': syscalls_names,
            'archs': {
                'alpha': syscalls_alpha,
                'arc': syscalls_arc,
                'arm64': syscalls_arm64,
                'armoabi': syscalls_armoabi,
                'arm': syscalls_arm,
                'avr32': syscalls_avr32,
                'blackfin': syscalls_blackfin,
                'c6x': syscalls_c6x,
                'cris': syscalls_cris,
                'csky': syscalls_csky,
                'frv': syscalls_frv,
                'h8300': syscalls_h8300,
                'hexagon': syscalls_hexagon,
                'i386': syscalls_i386,
                'ia64': syscalls_ia64,
                'm32r': syscalls_m32r,
                'm68k': syscalls_m68k,
                'metag': syscalls_metag,
                'microblaze': syscalls_microblaze,
                'mips64n32': syscalls_mips64n32,
                'mips64': syscalls_mips64,
                'mipso32': syscalls_mipso32,
                'mn10300': syscalls_mn10300,
                'nds32': syscalls_nds32,
                'nios2': syscalls_nios2,
                'openrisc': syscalls_openrisc,
                'parisc': syscalls_parisc,
                'powerpc64': syscalls_powerpc64,
                'powerpc': syscalls_powerpc,
                'riscv32': syscalls_riscv32,
                'riscv64': syscalls_riscv64,
                's390': syscalls_s390,
                's390x': syscalls_s390x,
                'score': syscalls_score,
                'sh64': syscalls_sh64,
                'sh': syscalls_sh,
                'sparc64': syscalls_sparc64,
                'sparc': syscalls_sparc,
                'tile64': syscalls_tile64,
                'tile': syscalls_tile,
                'unicore32': syscalls_unicore32,
                'x32': syscalls_x32,
                'x86_64': syscalls_x86_64,
                'xtensa': syscalls_xtensa,
            },
        }

        self.default_arch = os.uname().machine

    def __getitem__(self, syscall_name: str) -> int:
        """Returns number for requested system call.
        Host architecture would be used.
        """
        return self.get(syscall_name)

    def get(self, syscall_name: str, arch: str='') -> int:
        """Returns number for requested system call.
        Architecture can be provided by second argument (optional, host
        architecture would be used by default).
        """
        if arch == '':
            arch = self.default_arch

        try:
            return self.syscalls['archs'][arch][syscall_name]
        except KeyError:
            if syscall_name not in self.syscalls['names']:
                raise NoSuchSystemCall
            else:
                raise NotSupportedSystemCall

    def archs(self) -> dict:
        """Returns list of architectures supported by class.
        Some entries are no longer supported by mainline Linux kernel.
        """
        return list(self.syscalls['archs'].keys())

    def names(self) -> dict:
        """Returns list of system calls known by class.
        """
        return self.syscalls['names']



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_mips64 = {
    "_newselect": 5022,
    "_sysctl": 5152,
    "accept": 5042,
    "accept4": 5293,
    "access": 5020,
    "acct": 5158,
    "add_key": 5239,
    "adjtimex": 5154,
    "alarm": 5037,
    "bind": 5048,
    "bpf": 5315,
    "brk": 5012,
    "cachectl": 5198,
    "cacheflush": 5197,
    "capget": 5123,
    "capset": 5124,
    "chdir": 5078,
    "chmod": 5088,
    "chown": 5090,
    "chroot": 5156,
    "clock_adjtime": 5300,
    "clock_getres": 5223,
    "clock_gettime": 5222,
    "clock_nanosleep": 5224,
    "clock_settime": 5221,
    "clone": 5055,
    "clone3": 5435,
    "close": 5003,
    "close_range": 5436,
    "connect": 5041,
    "copy_file_range": 5320,
    "creat": 5083,
    "create_module": 5167,
    "delete_module": 5169,
    "dup": 5031,
    "dup2": 5032,
    "dup3": 5286,
    "epoll_create": 5207,
    "epoll_create1": 5285,
    "epoll_ctl": 5208,
    "epoll_pwait": 5272,
    "epoll_pwait2": 5441,
    "epoll_wait": 5209,
    "eventfd": 5278,
    "eventfd2": 5284,
    "execve": 5057,
    "execveat": 5316,
    "exit": 5058,
    "exit_group": 5205,
    "faccessat": 5259,
    "faccessat2": 5439,
    "fadvise64": 5215,
    "fallocate": 5279,
    "fanotify_init": 5295,
    "fanotify_mark": 5296,
    "fchdir": 5079,
    "fchmod": 5089,
    "fchmodat": 5258,
    "fchown": 5091,
    "fchownat": 5250,
    "fcntl": 5070,
    "fdatasync": 5073,
    "fgetxattr": 5185,
    "finit_module": 5307,
    "flistxattr": 5188,
    "flock": 5071,
    "fork": 5056,
    "fremovexattr": 5191,
    "fsconfig": 5431,
    "fsetxattr": 5182,
    "fsmount": 5432,
    "fsopen": 5430,
    "fspick": 5433,
    "fstat": 5005,
    "fstatfs": 5135,
    "fsync": 5072,
    "ftruncate": 5075,
    "futex": 5194,
    "futimesat": 5251,
    "get_kernel_syms": 5170,
    "get_mempolicy": 5228,
    "get_robust_list": 5269,
    "getcpu": 5271,
    "getcwd": 5077,
    "getdents": 5076,
    "getdents64": 5308,
    "getegid": 5106,
    "geteuid": 5105,
    "getgid": 5102,
    "getgroups": 5113,
    "getitimer": 5035,
    "getpeername": 5051,
    "getpgid": 5119,
    "getpgrp": 5109,
    "getpid": 5038,
    "getpmsg": 5174,
    "getppid": 5108,
    "getpriority": 5137,
    "getrandom": 5313,
    "getresgid": 5118,
    "getresuid": 5116,
    "getrlimit": 5095,
    "getrusage": 5096,
    "getsid": 5122,
    "getsockname": 5050,
    "getsockopt": 5054,
    "gettid": 5178,
    "gettimeofday": 5094,
    "getuid": 5100,
    "getxattr": 5183,
    "init_module": 5168,
    "inotify_add_watch": 5244,
    "inotify_init": 5243,
    "inotify_init1": 5288,
    "inotify_rm_watch": 5245,
    "io_cancel": 5204,
    "io_destroy": 5201,
    "io_getevents": 5202,
    "io_pgetevents": 5328,
    "io_setup": 5200,
    "io_submit": 5203,
    "io_uring_enter": 5426,
    "io_uring_register": 5427,
    "io_uring_setup": 5425,
    "ioctl": 5015,
    "ioprio_get": 5274,
    "ioprio_set": 5273,
    "kcmp": 5306,
    "kexec_load": 5270,
    "keyctl": 5241,
    "kill": 5060,
    "landlock_add_rule": 5445,
    "landlock_create_ruleset": 5444,
    "landlock_restrict_self": 5446,
    "lchown": 5092,
    "lgetxattr": 5184,
    "link": 5084,
    "linkat": 5255,
    "listen": 5049,
    "listxattr": 5186,
    "llistxattr": 5187,
    "lookup_dcookie": 5206,
    "lremovexattr": 5190,
    "lseek": 5008,
    "lsetxattr": 5181,
    "lstat": 5006,
    "madvise": 5027,
    "mbind": 5227,
    "membarrier": 5318,
    "memfd_create": 5314,
    "migrate_pages": 5246,
    "mincore": 5026,
    "mkdir": 5081,
    "mkdirat": 5248,
    "mknod": 5131,
    "mknodat": 5249,
    "mlock": 5146,
    "mlock2": 5319,
    "mlockall": 5148,
    "mmap": 5009,
    "mount": 5160,
    "mount_setattr": 5442,
    "move_mount": 5429,
    "move_pages": 5267,
    "mprotect": 5010,
    "mq_getsetattr": 5235,
    "mq_notify": 5234,
    "mq_open": 5230,
    "mq_timedreceive": 5233,
    "mq_timedsend": 5232,
    "mq_unlink": 5231,
    "mremap": 5024,
    "msgctl": 5069,
    "msgget": 5066,
    "msgrcv": 5068,
    "msgsnd": 5067,
    "msync": 5025,
    "munlock": 5147,
    "munlockall": 5149,
    "munmap": 5011,
    "name_to_handle_at": 5298,
    "nanosleep": 5034,
    "newfstatat": 5252,
    "nfsservctl": 5173,
    "open": 5002,
    "open_by_handle_at": 5299,
    "open_tree": 5428,
    "openat": 5247,
    "openat2": 5437,
    "pause": 5033,
    "perf_event_open": 5292,
    "personality": 5132,
    "pidfd_getfd": 5438,
    "pidfd_open": 5434,
    "pidfd_send_signal": 5424,
    "pipe": 5021,
    "pipe2": 5287,
    "pivot_root": 5151,
    "pkey_alloc": 5324,
    "pkey_free": 5325,
    "pkey_mprotect": 5323,
    "poll": 5007,
    "ppoll": 5261,
    "prctl": 5153,
    "pread64": 5016,
    "preadv": 5289,
    "preadv2": 5321,
    "prlimit64": 5297,
    "process_madvise": 5440,
    "process_mrelease": 5448,
    "process_vm_readv": 5304,
    "process_vm_writev": 5305,
    "pselect6": 5260,
    "ptrace": 5099,
    "pwrite64": 5017,
    "pwritev": 5290,
    "pwritev2": 5322,
    "query_module": 5171,
    "quotactl": 5172,
    "quotactl_fd": 5443,
    "read": 5000,
    "readahead": 5179,
    "readlink": 5087,
    "readlinkat": 5257,
    "readv": 5018,
    "reboot": 5164,
    "recvfrom": 5044,
    "recvmmsg": 5294,
    "recvmsg": 5046,
    "remap_file_pages": 5210,
    "removexattr": 5189,
    "rename": 5080,
    "renameat": 5254,
    "renameat2": 5311,
    "request_key": 5240,
    "restart_syscall": 5213,
    "rmdir": 5082,
    "rseq": 5327,
    "rt_sigaction": 5013,
    "rt_sigpending": 5125,
    "rt_sigprocmask": 5014,
    "rt_sigqueueinfo": 5127,
    "rt_sigreturn": 5211,
    "rt_sigsuspend": 5128,
    "rt_sigtimedwait": 5126,
    "rt_tgsigqueueinfo": 5291,
    "sched_get_priority_max": 5143,
    "sched_get_priority_min": 5144,
    "sched_getaffinity": 5196,
    "sched_getattr": 5310,
    "sched_getparam": 5140,
    "sched_getscheduler": 5142,
    "sched_rr_get_interval": 5145,
    "sched_setaffinity": 5195,
    "sched_setattr": 5309,
    "sched_setparam": 5139,
    "sched_setscheduler": 5141,
    "sched_yield": 5023,
    "seccomp": 5312,
    "semctl": 5064,
    "semget": 5062,
    "semop": 5063,
    "semtimedop": 5214,
    "sendfile": 5039,
    "sendmmsg": 5302,
    "sendmsg": 5045,
    "sendto": 5043,
    "set_mempolicy": 5229,
    "set_robust_list": 5268,
    "set_thread_area": 5242,
    "set_tid_address": 5212,
    "setdomainname": 5166,
    "setfsgid": 5121,
    "setfsuid": 5120,
    "setgid": 5104,
    "setgroups": 5114,
    "sethostname": 5165,
    "setitimer": 5036,
    "setns": 5303,
    "setpgid": 5107,
    "setpriority": 5138,
    "setregid": 5112,
    "setresgid": 5117,
    "setresuid": 5115,
    "setreuid": 5111,
    "setrlimit": 5155,
    "setsid": 5110,
    "setsockopt": 5053,
    "settimeofday": 5159,
    "setuid": 5103,
    "setxattr": 5180,
    "shmat": 5029,
    "shmctl": 5030,
    "shmdt": 5065,
    "shmget": 5028,
    "shutdown": 5047,
    "sigaltstack": 5129,
    "signalfd": 5276,
    "signalfd4": 5283,
    "socket": 5040,
    "socketpair": 5052,
    "splice": 5263,
    "stat": 5004,
    "statfs": 5134,
    "statx": 5326,
    "swapoff": 5163,
    "swapon": 5162,
    "symlink": 5086,
    "symlinkat": 5256,
    "sync": 5157,
    "sync_file_range": 5264,
    "syncfs": 5301,
    "sysfs": 5136,
    "sysinfo": 5097,
    "syslog": 5101,
    "sysmips": 5199,
    "tee": 5265,
    "tgkill": 5225,
    "timer_create": 5216,
    "timer_delete": 5220,
    "timer_getoverrun": 5219,
    "timer_gettime": 5218,
    "timer_settime": 5217,
    "timerfd": 5277,
    "timerfd_create": 5280,
    "timerfd_gettime": 5281,
    "timerfd_settime": 5282,
    "times": 5098,
    "tkill": 5192,
    "truncate": 5074,
    "umask": 5093,
    "umount2": 5161,
    "uname": 5061,
    "unlink": 5085,
    "unlinkat": 5253,
    "unshare": 5262,
    "userfaultfd": 5317,
    "ustat": 5133,
    "utime": 5130,
    "utimensat": 5275,
    "utimes": 5226,
    "vhangup": 5150,
    "vmsplice": 5266,
    "wait4": 5059,
    "waitid": 5237,
    "write": 5001,
    "writev": 5019,
}



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_m32r = {
    "_llseek": 140,
    "_newselect": 142,
    "_sysctl": 149,
    "access": 33,
    "acct": 51,
    "add_key": 286,
    "adjtimex": 124,
    "alarm": 27,
    "bdflush": 134,
    "brk": 45,
    "cachectl": 32,
    "capget": 184,
    "capset": 185,
    "chdir": 12,
    "chmod": 15,
    "chown32": 212,
    "chroot": 61,
    "clock_getres": 266,
    "clock_gettime": 265,
    "clock_nanosleep": 267,
    "clock_settime": 264,
    "clone": 120,
    "close": 6,
    "creat": 8,
    "delete_module": 129,
    "dup": 41,
    "dup2": 63,
    "epoll_create": 254,
    "epoll_ctl": 255,
    "epoll_pwait": 319,
    "epoll_wait": 256,
    "eventfd": 323,
    "execve": 11,
    "exit": 1,
    "exit_group": 252,
    "faccessat": 307,
    "fadvise64": 250,
    "fadvise64_64": 272,
    "fallocate": 324,
    "fchdir": 133,
    "fchmod": 94,
    "fchmodat": 306,
    "fchown32": 207,
    "fchownat": 298,
    "fcntl64": 221,
    "fdatasync": 148,
    "fgetxattr": 231,
    "flistxattr": 234,
    "flock": 143,
    "fork": 2,
    "fremovexattr": 237,
    "fsetxattr": 228,
    "fstat": 108,
    "fstat64": 197,
    "fstatat64": 300,
    "fstatfs": 100,
    "fstatfs64": 269,
    "fsync": 118,
    "ftruncate": 93,
    "ftruncate64": 194,
    "futex": 240,
    "futimesat": 299,
    "get_mempolicy": 275,
    "get_robust_list": 312,
    "get_thread_area": 244,
    "getcpu": 318,
    "getcwd": 183,
    "getdents": 141,
    "getdents64": 220,
    "getegid32": 202,
    "geteuid32": 201,
    "getgid32": 200,
    "getgroups32": 205,
    "getitimer": 105,
    "getpgid": 132,
    "getpgrp": 65,
    "getpid": 20,
    "getppid": 64,
    "getpriority": 96,
    "getresgid32": 211,
    "getresuid32": 209,
    "getrusage": 77,
    "getsid": 147,
    "gettid": 224,
    "gettimeofday": 78,
    "getuid32": 199,
    "getxattr": 229,
    "init_module": 128,
    "inotify_add_watch": 292,
    "inotify_init": 291,
    "inotify_rm_watch": 293,
    "io_cancel": 249,
    "io_destroy": 246,
    "io_getevents": 247,
    "io_setup": 245,
    "io_submit": 248,
    "ioctl": 54,
    "ioprio_get": 290,
    "ioprio_set": 289,
    "ipc": 117,
    "kexec_load": 283,
    "keyctl": 288,
    "kill": 37,
    "lchown32": 198,
    "lgetxattr": 230,
    "link": 9,
    "linkat": 303,
    "listxattr": 232,
    "llistxattr": 233,
    "lookup_dcookie": 253,
    "lremovexattr": 236,
    "lseek": 19,
    "lsetxattr": 227,
    "lstat": 107,
    "lstat64": 196,
    "madvise": 219,
    "mbind": 274,
    "migrate_pages": 294,
    "mincore": 218,
    "mkdir": 39,
    "mkdirat": 296,
    "mknod": 14,
    "mknodat": 297,
    "mlock": 150,
    "mlockall": 152,
    "mmap2": 192,
    "mount": 21,
    "move_pages": 317,
    "mprotect": 125,
    "mq_getsetattr": 282,
    "mq_notify": 281,
    "mq_open": 277,
    "mq_timedreceive": 280,
    "mq_timedsend": 279,
    "mq_unlink": 278,
    "mremap": 163,
    "msync": 144,
    "munlock": 151,
    "munlockall": 153,
    "munmap": 91,
    "nanosleep": 162,
    "nfsservctl": 169,
    "open": 5,
    "openat": 295,
    "pause": 29,
    "personality": 136,
    "pipe": 42,
    "pivot_root": 217,
    "poll": 168,
    "ppoll": 309,
    "prctl": 172,
    "pread64": 180,
    "pselect6": 308,
    "ptrace": 26,
    "pwrite64": 181,
    "quotactl": 131,
    "read": 3,
    "readahead": 225,
    "readlink": 85,
    "readlinkat": 305,
    "readv": 145,
    "reboot": 88,
    "remap_file_pages": 257,
    "removexattr": 235,
    "rename": 38,
    "renameat": 302,
    "request_key": 287,
    "restart_syscall": 0,
    "rmdir": 40,
    "rt_sigaction": 174,
    "rt_sigpending": 176,
    "rt_sigprocmask": 175,
    "rt_sigqueueinfo": 178,
    "rt_sigreturn": 173,
    "rt_sigsuspend": 179,
    "rt_sigtimedwait": 177,
    "sched_get_priority_max": 159,
    "sched_get_priority_min": 160,
    "sched_getaffinity": 242,
    "sched_getparam": 155,
    "sched_getscheduler": 157,
    "sched_rr_get_interval": 161,
    "sched_setaffinity": 241,
    "sched_setparam": 154,
    "sched_setscheduler": 156,
    "sched_yield": 158,
    "sendfile": 187,
    "sendfile64": 239,
    "set_mempolicy": 276,
    "set_robust_list": 311,
    "set_thread_area": 243,
    "set_tid_address": 258,
    "setdomainname": 121,
    "setfsgid32": 216,
    "setfsuid32": 215,
    "setgid32": 214,
    "setgroups32": 206,
    "sethostname": 74,
    "setitimer": 104,
    "setns": 325,
    "setpgid": 57,
    "setpriority": 97,
    "setregid32": 204,
    "setresgid32": 210,
    "setresuid32": 208,
    "setreuid32": 203,
    "setrlimit": 75,
    "setsid": 66,
    "settimeofday": 79,
    "setuid32": 213,
    "setxattr": 226,
    "sigaltstack": 186,
    "signalfd": 321,
    "socketcall": 102,
    "splice": 313,
    "stat": 106,
    "stat64": 195,
    "statfs": 99,
    "statfs64": 268,
    "stime": 25,
    "swapoff": 115,
    "swapon": 87,
    "symlink": 83,
    "symlinkat": 304,
    "sync": 36,
    "sync_file_range": 314,
    "sysfs": 135,
    "sysinfo": 116,
    "syslog": 103,
    "tas": 166,
    "tee": 315,
    "tgkill": 270,
    "time": 13,
    "timer_create": 259,
    "timer_delete": 263,
    "timer_getoverrun": 262,
    "timer_gettime": 261,
    "timer_settime": 260,
    "times": 43,
    "tkill": 238,
    "truncate": 92,
    "truncate64": 193,
    "ugetrlimit": 191,
    "umask": 60,
    "umount": 22,
    "umount2": 52,
    "uname": 122,
    "unlink": 10,
    "unlinkat": 301,
    "unshare": 310,
    "uselib": 86,
    "ustat": 62,
    "utime": 30,
    "utimensat": 320,
    "utimes": 271,
    "vfork": 190,
    "vhangup": 111,
    "vmsplice": 316,
    "vserver": 273,
    "wait4": 114,
    "waitid": 284,
    "waitpid": 7,
    "write": 4,
    "writev": 146,
}



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_unicore32 = {
    "accept": 202,
    "accept4": 242,
    "acct": 89,
    "add_key": 217,
    "adjtimex": 171,
    "bind": 200,
    "bpf": 280,
    "brk": 214,
    "capget": 90,
    "capset": 91,
    "chdir": 49,
    "chroot": 51,
    "clock_adjtime": 266,
    "clock_adjtime64": 405,
    "clock_getres": 114,
    "clock_getres_time64": 406,
    "clock_gettime": 113,
    "clock_gettime64": 403,
    "clock_nanosleep": 115,
    "clock_nanosleep_time64": 407,
    "clock_settime": 112,
    "clock_settime64": 404,
    "clone": 220,
    "close": 57,
    "connect": 203,
    "copy_file_range": 285,
    "delete_module": 106,
    "dup": 23,
    "dup3": 24,
    "epoll_create1": 20,
    "epoll_ctl": 21,
    "epoll_pwait": 22,
    "eventfd2": 19,
    "execve": 221,
    "execveat": 281,
    "exit": 93,
    "exit_group": 94,
    "faccessat": 48,
    "faccessat2": 439,
    "fadvise64_64": 223,
    "fallocate": 47,
    "fanotify_init": 262,
    "fanotify_mark": 263,
    "fchdir": 50,
    "fchmod": 52,
    "fchmodat": 53,
    "fchown": 55,
    "fchownat": 54,
    "fcntl64": 25,
    "fdatasync": 83,
    "fgetxattr": 10,
    "finit_module": 273,
    "flistxattr": 13,
    "flock": 32,
    "fremovexattr": 16,
    "fsconfig": 431,
    "fsetxattr": 7,
    "fsmount": 432,
    "fsopen": 430,
    "fspick": 433,
    "fstat64": 80,
    "fstatat64": 79,
    "fstatfs64": 44,
    "fsync": 82,
    "ftruncate64": 46,
    "futex": 98,
    "futex_time64": 422,
    "get_mempolicy": 236,
    "get_robust_list": 100,
    "getcpu": 168,
    "getcwd": 17,
    "getdents64": 61,
    "getegid": 177,
    "geteuid": 175,
    "getgid": 176,
    "getgroups": 158,
    "getitimer": 102,
    "getpeername": 205,
    "getpgid": 155,
    "getpid": 172,
    "getppid": 173,
    "getpriority": 141,
    "getrandom": 278,
    "getresgid": 150,
    "getresuid": 148,
    "getrlimit": 163,
    "getrusage": 165,
    "getsid": 156,
    "getsockname": 204,
    "getsockopt": 209,
    "gettid": 178,
    "gettimeofday": 169,
    "getuid": 174,
    "getxattr": 8,
    "init_module": 105,
    "inotify_add_watch": 27,
    "inotify_init1": 26,
    "inotify_rm_watch": 28,
    "io_cancel": 3,
    "io_destroy": 1,
    "io_getevents": 4,
    "io_pgetevents": 292,
    "io_pgetevents_time64": 416,
    "io_setup": 0,
    "io_submit": 2,
    "io_uring_enter": 426,
    "io_uring_register": 427,
    "io_uring_setup": 425,
    "ioctl": 29,
    "ioprio_get": 31,
    "ioprio_set": 30,
    "kcmp": 272,
    "kexec_file_load": 294,
    "kexec_load": 104,
    "keyctl": 219,
    "kill": 129,
    "lgetxattr": 9,
    "linkat": 37,
    "listen": 201,
    "listxattr": 11,
    "llistxattr": 12,
    "lookup_dcookie": 18,
    "lremovexattr": 15,
    "lsetxattr": 6,
    "madvise": 233,
    "mbind": 235,
    "membarrier": 283,
    "memfd_create": 279,
    "migrate_pages": 238,
    "mincore": 232,
    "mkdirat": 34,
    "mknodat": 33,
    "mlock": 228,
    "mlock2": 284,
    "mlockall": 230,
    "mmap2": 222,
    "mount": 40,
    "move_mount": 429,
    "move_pages": 239,
    "mprotect": 226,
    "mq_getsetattr": 185,
    "mq_notify": 184,
    "mq_open": 180,
    "mq_timedreceive": 183,
    "mq_timedreceive_time64": 419,
    "mq_timedsend": 182,
    "mq_timedsend_time64": 418,
    "mq_unlink": 181,
    "mremap": 216,
    "msgctl": 187,
    "msgget": 186,
    "msgrcv": 188,
    "msgsnd": 189,
    "msync": 227,
    "munlock": 229,
    "munlockall": 231,
    "munmap": 215,
    "name_to_handle_at": 264,
    "nanosleep": 101,
    "nfsservctl": 42,
    "open_by_handle_at": 265,
    "open_tree": 428,
    "openat": 56,
    "openat2": 437,
    "perf_event_open": 241,
    "personality": 92,
    "pidfd_getfd": 438,
    "pidfd_open": 434,
    "pidfd_send_signal": 424,
    "pipe2": 59,
    "pivot_root": 41,
    "pkey_alloc": 289,
    "pkey_free": 290,
    "pkey_mprotect": 288,
    "ppoll": 73,
    "ppoll_time64": 414,
    "prctl": 167,
    "pread64": 67,
    "preadv": 69,
    "preadv2": 286,
    "prlimit64": 261,
    "process_vm_readv": 270,
    "process_vm_writev": 271,
    "pselect6": 72,
    "pselect6_time64": 413,
    "ptrace": 117,
    "pwrite64": 68,
    "pwritev": 70,
    "pwritev2": 287,
    "quotactl": 60,
    "read": 63,
    "readahead": 213,
    "readlinkat": 78,
    "readv": 65,
    "reboot": 142,
    "recvfrom": 207,
    "recvmmsg": 243,
    "recvmmsg_time64": 417,
    "recvmsg": 212,
    "remap_file_pages": 234,
    "removexattr": 14,
    "renameat": 38,
    "renameat2": 276,
    "request_key": 218,
    "restart_syscall": 128,
    "rseq": 293,
    "rt_sigaction": 134,
    "rt_sigpending": 136,
    "rt_sigprocmask": 135,
    "rt_sigqueueinfo": 138,
    "rt_sigreturn": 139,
    "rt_sigsuspend": 133,
    "rt_sigtimedwait": 137,
    "rt_sigtimedwait_time64": 421,
    "rt_tgsigqueueinfo": 240,
    "sched_get_priority_max": 125,
    "sched_get_priority_min": 126,
    "sched_getaffinity": 123,
    "sched_getattr": 275,
    "sched_getparam": 121,
    "sched_getscheduler": 120,
    "sched_rr_get_interval": 127,
    "sched_rr_get_interval_time64": 423,
    "sched_setaffinity": 122,
    "sched_setattr": 274,
    "sched_setparam": 118,
    "sched_setscheduler": 119,
    "sched_yield": 124,
    "seccomp": 277,
    "semctl": 191,
    "semget": 190,
    "semop": 193,
    "semtimedop": 192,
    "semtimedop_time64": 420,
    "sendfile64": 71,
    "sendmmsg": 269,
    "sendmsg": 211,
    "sendto": 206,
    "set_mempolicy": 237,
    "set_robust_list": 99,
    "set_tid_address": 96,
    "setdomainname": 162,
    "setfsgid": 152,
    "setfsuid": 151,
    "setgid": 144,
    "setgroups": 159,
    "sethostname": 161,
    "setitimer": 103,
    "setns": 268,
    "setpgid": 154,
    "setpriority": 140,
    "setregid": 143,
    "setresgid": 149,
    "setresuid": 147,
    "setreuid": 145,
    "setrlimit": 164,
    "setsid": 157,
    "setsockopt": 208,
    "settimeofday": 170,
    "setuid": 146,
    "setxattr": 5,
    "shmat": 196,
    "shmctl": 195,
    "shmdt": 197,
    "shmget": 194,
    "shutdown": 210,
    "sigaltstack": 132,
    "signalfd4": 74,
    "socket": 198,
    "socketpair": 199,
    "splice": 76,
    "statfs64": 43,
    "statx": 291,
    "swapoff": 225,
    "swapon": 224,
    "symlinkat": 36,
    "sync": 81,
    "sync_file_range": 84,
    "syncfs": 267,
    "sysinfo": 179,
    "syslog": 116,
    "tee": 77,
    "tgkill": 131,
    "timer_create": 107,
    "timer_delete": 111,
    "timer_getoverrun": 109,
    "timer_gettime": 108,
    "timer_gettime64": 408,
    "timer_settime": 110,
    "timer_settime64": 409,
    "timerfd_create": 85,
    "timerfd_gettime": 87,
    "timerfd_gettime64": 410,
    "timerfd_settime": 86,
    "timerfd_settime64": 411,
    "times": 153,
    "tkill": 130,
    "truncate64": 45,
    "umask": 166,
    "umount2": 39,
    "uname": 160,
    "unlinkat": 35,
    "unshare": 97,
    "userfaultfd": 282,
    "utimensat": 88,
    "utimensat_time64": 412,
    "vhangup": 58,
    "vmsplice": 75,
    "wait4": 260,
    "waitid": 95,
    "write": 64,
    "writev": 66,
}



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_alpha = {
    "_sysctl": 319,
    "accept": 99,
    "accept4": 502,
    "access": 33,
    "acct": 51,
    "add_key": 439,
    "adjtimex": 366,
    "bdflush": 300,
    "bind": 104,
    "bpf": 515,
    "brk": 17,
    "capget": 368,
    "capset": 369,
    "chdir": 12,
    "chmod": 15,
    "chown": 16,
    "chroot": 61,
    "clock_adjtime": 499,
    "clock_getres": 421,
    "clock_gettime": 420,
    "clock_nanosleep": 422,
    "clock_settime": 419,
    "clone": 312,
    "close": 6,
    "close_range": 546,
    "connect": 98,
    "copy_file_range": 519,
    "create_module": 306,
    "delete_module": 308,
    "dipc": 373,
    "dup": 41,
    "dup2": 90,
    "dup3": 487,
    "epoll_create": 407,
    "epoll_create1": 486,
    "epoll_ctl": 408,
    "epoll_pwait": 474,
    "epoll_pwait2": 551,
    "epoll_wait": 409,
    "eventfd": 478,
    "eventfd2": 485,
    "exec_with_loader": 25,
    "execve": 59,
    "execveat": 513,
    "exit": 1,
    "exit_group": 405,
    "faccessat": 462,
    "faccessat2": 549,
    "fadvise64": 413,
    "fallocate": 480,
    "fanotify_init": 494,
    "fanotify_mark": 495,
    "fchdir": 13,
    "fchmod": 124,
    "fchmodat": 461,
    "fchown": 123,
    "fchownat": 453,
    "fcntl": 92,
    "fdatasync": 447,
    "fgetxattr": 387,
    "finit_module": 507,
    "flistxattr": 390,
    "flock": 131,
    "fork": 2,
    "fremovexattr": 393,
    "fsconfig": 541,
    "fsetxattr": 384,
    "fsmount": 542,
    "fsopen": 540,
    "fspick": 543,
    "fstat": 91,
    "fstat64": 427,
    "fstatat64": 455,
    "fstatfs": 329,
    "fstatfs64": 529,
    "fsync": 95,
    "ftruncate": 130,
    "futex": 394,
    "futimesat": 454,
    "get_kernel_syms": 309,
    "get_mempolicy": 430,
    "get_robust_list": 467,
    "getcpu": 473,
    "getcwd": 367,
    "getdents": 305,
    "getdents64": 377,
    "getdtablesize": 89,
    "getegid": 530,
    "geteuid": 531,
    "getgid": 47,
    "getgroups": 79,
    "gethostname": 87,
    "getitimer": 361,
    "getpagesize": 64,
    "getpeername": 141,
    "getpgid": 233,
    "getpgrp": 63,
    "getpid": 20,
    "getppid": 532,
    "getpriority": 100,
    "getrandom": 511,
    "getresgid": 372,
    "getresuid": 344,
    "getrlimit": 144,
    "getrusage": 364,
    "getsid": 234,
    "getsockname": 150,
    "getsockopt": 118,
    "gettid": 378,
    "gettimeofday": 359,
    "getuid": 24,
    "getxattr": 385,
    "getxgid": 47,
    "getxpid": 20,
    "getxuid": 24,
    "init_module": 307,
    "inotify_add_watch": 445,
    "inotify_init": 444,
    "inotify_init1": 489,
    "inotify_rm_watch": 446,
    "io_cancel": 402,
    "io_destroy": 399,
    "io_getevents": 400,
    "io_pgetevents": 523,
    "io_setup": 398,
    "io_submit": 401,
    "io_uring_enter": 536,
    "io_uring_register": 537,
    "io_uring_setup": 535,
    "ioctl": 54,
    "ioprio_get": 443,
    "ioprio_set": 442,
    "kcmp": 506,
    "kexec_load": 448,
    "keyctl": 441,
    "kill": 37,
    "landlock_add_rule": 555,
    "landlock_create_ruleset": 554,
    "landlock_restrict_self": 556,
    "lchown": 208,
    "lgetxattr": 386,
    "link": 9,
    "linkat": 458,
    "listen": 106,
    "listxattr": 388,
    "llistxattr": 389,
    "lookup_dcookie": 406,
    "lremovexattr": 392,
    "lseek": 19,
    "lsetxattr": 383,
    "lstat": 68,
    "lstat64": 426,
    "madvise": 75,
    "mbind": 429,
    "membarrier": 517,
    "memfd_create": 512,
    "migrate_pages": 449,
    "mincore": 375,
    "mkdir": 136,
    "mkdirat": 451,
    "mknod": 14,
    "mknodat": 452,
    "mlock": 314,
    "mlock2": 518,
    "mlockall": 316,
    "mmap": 71,
    "mount": 302,
    "mount_setattr": 552,
    "move_mount": 539,
    "move_pages": 472,
    "mprotect": 74,
    "mq_getsetattr": 437,
    "mq_notify": 436,
    "mq_open": 432,
    "mq_timedreceive": 435,
    "mq_timedsend": 434,
    "mq_unlink": 433,
    "mremap": 341,
    "msgctl": 200,
    "msgget": 201,
    "msgrcv": 202,
    "msgsnd": 203,
    "msync": 217,
    "munlock": 315,
    "munlockall": 317,
    "munmap": 73,
    "name_to_handle_at": 497,
    "nanosleep": 340,
    "nfsservctl": 342,
    "old_adjtimex": 303,
    "oldumount": 321,
    "open": 45,
    "open_by_handle_at": 498,
    "open_tree": 538,
    "openat": 450,
    "openat2": 547,
    "osf_adjtime": 140,
    "osf_afs_syscall": 258,
    "osf_alt_plock": 181,
    "osf_alt_setsid": 188,
    "osf_alt_sigpending": 187,
    "osf_asynch_daemon": 163,
    "osf_audcntl": 252,
    "osf_audgen": 253,
    "osf_chflags": 34,
    "osf_execve": 11,
    "osf_exportfs": 169,
    "osf_fchflags": 35,
    "osf_fdatasync": 261,
    "osf_fpathconf": 248,
    "osf_fstat": 226,
    "osf_fstatfs": 161,
    "osf_fstatfs64": 228,
    "osf_fuser": 243,
    "osf_getaddressconf": 214,
    "osf_getdirentries": 159,
    "osf_getdomainname": 165,
    "osf_getfh": 164,
    "osf_getfsstat": 18,
    "osf_gethostid": 142,
    "osf_getitimer": 86,
    "osf_getlogin": 49,
    "osf_getmnt": 184,
    "osf_getrusage": 117,
    "osf_getsysinfo": 256,
    "osf_gettimeofday": 116,
    "osf_kloadcall": 223,
    "osf_kmodcall": 77,
    "osf_lstat": 225,
    "osf_memcntl": 260,
    "osf_mincore": 78,
    "osf_mount": 21,
    "osf_mremap": 65,
    "osf_msfs_syscall": 240,
    "osf_msleep": 215,
    "osf_mvalid": 213,
    "osf_mwakeup": 216,
    "osf_naccept": 30,
    "osf_nfssvc": 158,
    "osf_ngetpeername": 31,
    "osf_ngetsockname": 32,
    "osf_nrecvfrom": 29,
    "osf_nrecvmsg": 27,
    "osf_nsendmsg": 28,
    "osf_ntp_adjtime": 245,
    "osf_ntp_gettime": 246,
    "osf_old_creat": 8,
    "osf_old_fstat": 62,
    "osf_old_getpgrp": 81,
    "osf_old_killpg": 146,
    "osf_old_lstat": 40,
    "osf_old_open": 5,
    "osf_old_sigaction": 46,
    "osf_old_sigblock": 109,
    "osf_old_sigreturn": 139,
    "osf_old_sigsetmask": 110,
    "osf_old_sigvec": 108,
    "osf_old_stat": 38,
    "osf_old_vadvise": 72,
    "osf_old_vtrace": 115,
    "osf_old_wait": 84,
    "osf_oldquota": 149,
    "osf_pathconf": 247,
    "osf_pid_block": 153,
    "osf_pid_unblock": 154,
    "osf_plock": 107,
    "osf_priocntlset": 237,
    "osf_profil": 44,
    "osf_proplist_syscall": 244,
    "osf_reboot": 55,
    "osf_revoke": 56,
    "osf_sbrk": 69,
    "osf_security": 222,
    "osf_select": 93,
    "osf_set_program_attributes": 43,
    "osf_set_speculative": 239,
    "osf_sethostid": 143,
    "osf_setitimer": 83,
    "osf_setlogin": 50,
    "osf_setsysinfo": 257,
    "osf_settimeofday": 122,
    "osf_shmat": 209,
    "osf_signal": 218,
    "osf_sigprocmask": 48,
    "osf_sigsendset": 238,
    "osf_sigstack": 112,
    "osf_sigwaitprim": 157,
    "osf_sstk": 70,
    "osf_stat": 224,
    "osf_statfs": 160,
    "osf_statfs64": 227,
    "osf_subsys_info": 255,
    "osf_swapctl": 259,
    "osf_swapon": 199,
    "osf_syscall": 0,
    "osf_sysinfo": 241,
    "osf_table": 85,
    "osf_uadmin": 242,
    "osf_usleep_thread": 251,
    "osf_uswitch": 250,
    "osf_utc_adjtime": 220,
    "osf_utc_gettime": 219,
    "osf_utimes": 138,
    "osf_utsname": 207,
    "osf_wait4": 7,
    "osf_waitid": 236,
    "pciconfig_iobase": 376,
    "pciconfig_read": 345,
    "pciconfig_write": 346,
    "perf_event_open": 493,
    "personality": 324,
    "pidfd_getfd": 548,
    "pidfd_open": 544,
    "pidfd_send_signal": 534,
    "pipe": 42,
    "pipe2": 488,
    "pivot_root": 374,
    "pkey_alloc": 525,
    "pkey_free": 526,
    "pkey_mprotect": 524,
    "poll": 94,
    "ppoll": 464,
    "prctl": 348,
    "pread64": 349,
    "preadv": 490,
    "preadv2": 520,
    "prlimit64": 496,
    "process_madvise": 550,
    "process_mrelease": 558,
    "process_vm_readv": 504,
    "process_vm_writev": 505,
    "pselect6": 463,
    "ptrace": 26,
    "pwrite64": 350,
    "pwritev": 491,
    "pwritev2": 521,
    "query_module": 347,
    "quotactl": 148,
    "quotactl_fd": 553,
    "read": 3,
    "readahead": 379,
    "readlink": 58,
    "readlinkat": 460,
    "readv": 120,
    "reboot": 311,
    "recv": 102,
    "recvfrom": 125,
    "recvmmsg": 479,
    "recvmsg": 113,
    "remap_file_pages": 410,
    "removexattr": 391,
    "rename": 128,
    "renameat": 457,
    "renameat2": 510,
    "request_key": 440,
    "restart_syscall": 412,
    "rmdir": 137,
    "rseq": 527,
    "rt_sigaction": 352,
    "rt_sigpending": 354,
    "rt_sigprocmask": 353,
    "rt_sigqueueinfo": 356,
    "rt_sigreturn": 351,
    "rt_sigsuspend": 357,
    "rt_sigtimedwait": 355,
    "rt_tgsigqueueinfo": 492,
    "sched_get_priority_max": 335,
    "sched_get_priority_min": 336,
    "sched_getaffinity": 396,
    "sched_getattr": 509,
    "sched_getparam": 331,
    "sched_getscheduler": 333,
    "sched_rr_get_interval": 337,
    "sched_setaffinity": 395,
    "sched_setattr": 508,
    "sched_setparam": 330,
    "sched_setscheduler": 332,
    "sched_yield": 334,
    "seccomp": 514,
    "select": 358,
    "semctl": 204,
    "semget": 205,
    "semop": 206,
    "semtimedop": 423,
    "send": 101,
    "sendfile": 370,
    "sendmmsg": 503,
    "sendmsg": 114,
    "sendto": 133,
    "set_mempolicy": 431,
    "set_robust_list": 466,
    "set_tid_address": 411,
    "setdomainname": 166,
    "setfsgid": 326,
    "setfsuid": 325,
    "setgid": 132,
    "setgroups": 80,
    "sethae": 301,
    "sethostname": 88,
    "setitimer": 362,
    "setns": 501,
    "setpgid": 39,
    "setpgrp": 82,
    "setpriority": 96,
    "setregid": 127,
    "setresgid": 371,
    "setresuid": 343,
    "setreuid": 126,
    "setrlimit": 145,
    "setsid": 147,
    "setsockopt": 105,
    "settimeofday": 360,
    "setuid": 23,
    "setxattr": 382,
    "shmat": 209,
    "shmctl": 210,
    "shmdt": 211,
    "shmget": 212,
    "shutdown": 134,
    "sigaction": 156,
    "sigaltstack": 235,
    "signalfd": 476,
    "signalfd4": 484,
    "sigpending": 52,
    "sigreturn": 103,
    "sigsuspend": 111,
    "socket": 97,
    "socketpair": 135,
    "splice": 468,
    "stat": 67,
    "stat64": 425,
    "statfs": 328,
    "statfs64": 528,
    "statx": 522,
    "swapoff": 304,
    "swapon": 322,
    "symlink": 57,
    "symlinkat": 459,
    "sync": 36,
    "sync_file_range": 469,
    "syncfs": 500,
    "sysfs": 254,
    "sysinfo": 318,
    "syslog": 310,
    "tee": 470,
    "tgkill": 424,
    "timer_create": 414,
    "timer_delete": 418,
    "timer_getoverrun": 417,
    "timer_gettime": 416,
    "timer_settime": 415,
    "timerfd": 477,
    "timerfd_create": 481,
    "timerfd_gettime": 483,
    "timerfd_settime": 482,
    "times": 323,
    "tkill": 381,
    "truncate": 129,
    "umask": 60,
    "umount": 22,
    "umount2": 22,
    "uname": 339,
    "unlink": 10,
    "unlinkat": 456,
    "unshare": 465,
    "uselib": 313,
    "userfaultfd": 516,
    "ustat": 327,
    "utimensat": 475,
    "utimes": 363,
    "vfork": 66,
    "vhangup": 76,
    "vmsplice": 471,
    "wait4": 365,
    "waitid": 438,
    "write": 4,
    "writev": 121,
}



#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_mips64n32 = {
    "_newselect": 6022,
    "_sysctl": 6152,
    "accept": 6042,
    "accept4": 6297,
    "access": 6020,
    "acct": 6158,
    "add_key": 6243,
    "adjtimex": 6154,
    "alarm": 6037,
    "bind": 6048,
    "bpf": 6319,
    "brk": 6012,
    "cachectl": 6198,
    "cacheflush": 6197,
    "capget": 6123,
    "capset": 6124,
    "chdir": 6078,
    "chmod": 6088,
    "chown": 6090,
    "chroot": 6156,
    "clock_adjtime": 6305,
    "clock_adjtime64": 6405,
    "clock_getres": 6227,
    "clock_getres_time64": 6406,
    "clock_gettime": 6226,
    "clock_gettime64": 6403,
    "clock_nanosleep": 6228,
    "clock_nanosleep_time64": 6407,
    "clock_settime": 6225,
    "clock_settime64": 6404,
    "clone": 6055,
    "clone3": 6435,
    "close": 6003,
    "close_range": 6436,
    "connect": 6041,
    "copy_file_range": 6324,
    "creat": 6083,
    "create_module": 6167,
    "delete_module": 6169,
    "dup": 6031,
    "dup2": 6032,
    "dup3": 6290,
    "epoll_create": 6207,
    "epoll_create1": 6289,
    "epoll_ctl": 6208,
    "epoll_pwait": 6276,
    "epoll_pwait2": 6441,
    "epoll_wait": 6209,
    "eventfd": 6282,
    "eventfd2": 6288,
    "execve": 6057,
    "execveat": 6320,
    "exit": 6058,
    "exit_group": 6205,
    "faccessat": 6263,
    "faccessat2": 6439,
    "fadvise64": 6216,
    "fallocate": 6283,
    "fanotify_init": 6300,
    "fanotify_mark": 6301,
    "fchdir": 6079,
    "fchmod": 6089,
    "fchmodat": 6262,
    "fchown": 6091,
    "fchownat": 6254,
    "fcntl": 6070,
    "fcntl64": 6212,
    "fdatasync": 6073,
    "fgetxattr": 6185,
    "finit_module": 6312,
    "flistxattr": 6188,
    "flock": 6071,
    "fork": 6056,
    "fremovexattr": 6191,
    "fsconfig": 6431,
    "fsetxattr": 6182,
    "fsmount": 6432,
    "fsopen": 6430,
    "fspick": 6433,
    "fstat": 6005,
    "fstatfs": 6135,
    "fstatfs64": 6218,
    "fsync": 6072,
    "ftruncate": 6075,
    "futex": 6194,
    "futex_time64": 6422,
    "futimesat": 6255,
    "get_kernel_syms": 6170,
    "get_mempolicy": 6232,
    "get_robust_list": 6273,
    "getcpu": 6275,
    "getcwd": 6077,
    "getdents": 6076,
    "getdents64": 6299,
    "getegid": 6106,
    "geteuid": 6105,
    "getgid": 6102,
    "getgroups": 6113,
    "getitimer": 6035,
    "getpeername": 6051,
    "getpgid": 6119,
    "getpgrp": 6109,
    "getpid": 6038,
    "getpmsg": 6174,
    "getppid": 6108,
    "getpriority": 6137,
    "getrandom": 6317,
    "getresgid": 6118,
    "getresuid": 6116,
    "getrlimit": 6095,
    "getrusage": 6096,
    "getsid": 6122,
    "getsockname": 6050,
    "getsockopt": 6054,
    "gettid": 6178,
    "gettimeofday": 6094,
    "getuid": 6100,
    "getxattr": 6183,
    "init_module": 6168,
    "inotify_add_watch": 6248,
    "inotify_init": 6247,
    "inotify_init1": 6292,
    "inotify_rm_watch": 6249,
    "io_cancel": 6204,
    "io_destroy": 6201,
    "io_getevents": 6202,
    "io_pgetevents": 6332,
    "io_pgetevents_time64": 6416,
    "io_setup": 6200,
    "io_submit": 6203,
    "io_uring_enter": 6426,
    "io_uring_register": 6427,
    "io_uring_setup": 6425,
    "ioctl": 6015,
    "ioprio_get": 6278,
    "ioprio_set": 6277,
    "kcmp": 6311,
    "kexec_load": 6274,
    "keyctl": 6245,
    "kill": 6060,
    "landlock_add_rule": 6445,
    "landlock_create_ruleset": 6444,
    "landlock_restrict_self": 6446,
    "lchown": 6092,
    "lgetxattr": 6184,
    "link": 6084,
    "linkat": 6259,
    "listen": 6049,
    "listxattr": 6186,
    "llistxattr": 6187,
    "lookup_dcookie": 6206,
    "lremovexattr": 6190,
    "lseek": 6008,
    "lsetxattr": 6181,
    "lstat": 6006,
    "madvise": 6027,
    "mbind": 6231,
    "membarrier": 6322,
    "memfd_create": 6318,
    "migrate_pages": 6250,
    "mincore": 6026,
    "mkdir": 6081,
    "mkdirat": 6252,
    "mknod": 6131,
    "mknodat": 6253,
    "mlock": 6146,
    "mlock2": 6323,
    "mlockall": 6148,
    "mmap": 6009,
    "mount": 6160,
    "mount_setattr": 6442,
    "move_mount": 6429,
    "move_pages": 6271,
    "mprotect": 6010,
    "mq_getsetattr": 6239,
    "mq_notify": 6238,
    "mq_open": 6234,
    "mq_timedreceive": 6237,
    "mq_timedreceive_time64": 6419,
    "mq_timedsend": 6236,
    "mq_timedsend_time64": 6418,
    "mq_unlink": 6235,
    "mremap": 6024,
    "msgctl": 6069,
    "msgget": 6066,
    "msgrcv": 6068,
    "msgsnd": 6067,
    "msync": 6025,
    "munlock": 6147,
    "munlockall": 6149,
    "munmap": 6011,
    "name_to_handle_at": 6303,
    "nanosleep": 6034,
    "newfstatat": 6256,
    "nfsservctl": 6173,
    "open": 6002,
    "open_by_handle_at": 6304,
    "open_tree": 6428,
    "openat": 6251,
    "openat2": 6437,
    "pause": 6033,
    "perf_event_open": 6296,
    "personality": 6132,
    "pidfd_getfd": 6438,
    "pidfd_open": 6434,
    "pidfd_send_signal": 6424,
    "pipe": 6021,
    "pipe2": 6291,
    "pivot_root": 6151,
    "pkey_alloc": 6328,
    "pkey_free": 6329,
    "pkey_mprotect": 6327,
    "poll": 6007,
    "ppoll": 6265,
    "ppoll_time64": 6414,
    "prctl": 6153,
    "pread64": 6016,
    "preadv": 6293,
    "preadv2": 6325,
    "prlimit64": 6302,
    "process_madvise": 6440,
    "process_mrelease": 6448,
    "process_vm_readv": 6309,
    "process_vm_writev": 6310,
    "pselect6": 6264,
    "pselect6_time64": 6413,
    "ptrace": 6099,
    "pwrite64": 6017,
    "pwritev": 6294,
    "pwritev2": 6326,
    "query_module": 6171,
    "quotactl": 6172,
    "quotactl_fd": 6443,
    "read": 6000,
    "readahead": 6179,
    "readlink": 6087,
    "readlinkat": 6261,
    "readv": 6018,
    "reboot": 6164,
    "recvfrom": 6044,
    "recvmmsg": 6298,
    "recvmmsg_time64": 6417,
    "recvmsg": 6046,
    "remap_file_pages": 6210,
    "removexattr": 6189,
    "rename": 6080,
    "renameat": 6258,
    "renameat2": 6315,
    "request_key": 6244,
    "restart_syscall": 6214,
    "rmdir": 6082,
    "rseq": 6331,
    "rt_sigaction": 6013,
    "rt_sigpending": 6125,
    "rt_sigprocmask": 6014,
    "rt_sigqueueinfo": 6127,
    "rt_sigreturn": 6211,
    "rt_sigsuspend": 6128,
    "rt_sigtimedwait": 6126,
    "rt_sigtimedwait_time64": 6421,
    "rt_tgsigqueueinfo": 6295,
    "sched_get_priority_max": 6143,
    "sched_get_priority_min": 6144,
    "sched_getaffinity": 6196,
    "sched_getattr": 6314,
    "sched_getparam": 6140,
    "sched_getscheduler": 6142,
    "sched_rr_get_interval": 6145,
    "sched_rr_get_interval_time64": 6423,
    "sched_setaffinity": 6195,
    "sched_setattr": 6313,
    "sched_setparam": 6139,
    "sched_setscheduler": 6141,
    "sched_yield": 6023,
    "seccomp": 6316,
    "semctl": 6064,
    "semget": 6062,
    "semop": 6063,
    "semtimedop": 6215,
    "semtimedop_time64": 6420,
    "sendfile": 6039,
    "sendfile64": 6219,
    "sendmmsg": 6307,
    "sendmsg": 6045,
    "sendto": 6043,
    "set_mempolicy": 6233,
    "set_robust_list": 6272,
    "set_thread_area": 6246,
    "set_tid_address": 6213,
    "setdomainname": 6166,
    "setfsgid": 6121,
    "setfsuid": 6120,
    "setgid": 6104,
    "setgroups": 6114,
    "sethostname": 6165,
    "setitimer": 6036,
    "setns": 6308,
    "setpgid": 6107,
    "setpriority": 6138,
    "setregid": 6112,
    "setresgid": 6117,
    "setresuid": 6115,
    "setreuid": 6111,
    "setrlimit": 6155,
    "setsid": 6110,
    "setsockopt": 6053,
    "settimeofday": 6159,
    "setuid": 6103,
    "setxattr": 6180,
    "shmat": 6029,
    "shmctl": 6030,
    "shmdt": 6065,
    "shmget": 6028,
    "shutdown": 6047,
    "sigaltstack": 6129,
    "signalfd": 6280,
    "signalfd4": 6287,
    "socket": 6040,
    "socketpair": 6052,
    "splice": 6267,
    "stat": 6004,
    "statfs": 6134,
    "statfs64": 6217,
    "statx": 6330,
    "swapoff": 6163,
    "swapon": 6162,
    "symlink": 6086,
    "symlinkat": 6260,
    "sync": 6157,
    "sync_file_range": 6268,
    "syncfs": 6306,
    "sysfs": 6136,
    "sysinfo": 6097,
    "syslog": 6101,
    "sysmips": 6199,
    "tee": 6269,
    "tgkill": 6229,
    "timer_create": 6220,
    "timer_delete": 6224,
    "timer_getoverrun": 6223,
    "timer_gettime": 6222,
    "timer_gettime64": 6408,
    "timer_settime": 6221,
    "timer_settime64": 6409,
    "timerfd": 6281,
    "timerfd_create": 6284,
    "timerfd_gettime": 6285,
    "timerfd_gettime64": 6410,
    "timerfd_settime": 6286,
    "timerfd_settime64": 6411,
    "times": 6098,
    "tkill": 6192,
    "truncate": 6074,
    "umask": 6093,
    "umount2": 6161,
    "uname": 6061,
    "unlink": 6085,
    "unlinkat": 6257,
    "unshare": 6266,
    "userfaultfd": 6321,
    "ustat": 6133,
    "utime": 6130,
    "utimensat": 6279,
    "utimensat_time64": 6412,
    "utimes": 6230,
    "vhangup": 6150,
    "vmsplice": 6270,
    "wait4": 6059,
    "waitid": 6241,
    "write": 6001,
    "writev": 6019,
}



#!/usr/bin/python3

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="system-calls",
    version="5.15.3",
    author="Marcin Juszkiewicz",
    author_email="marcin-python@juszkiewicz.com.pl",
    description="Python module to check for system call numbers",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hrw/python-syscalls",
    project_urls={
        "Bug Tracker": "https://github.com/hrw/python-syscalls/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
    ],
    packages=["system_calls", "system_calls/tables/"],
    python_requires=">=3.6",
    license_files=["LICENSE"],
    scripts=["bin/syscall"],
)
